#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

Adoptada i proclamada per l'Assemblea General de les Nacions Unides, resolució 217 A (III), de 10 de desembre de 1948

Declaració Universal de Drets Humans
PREÀMBUL
Considerant que el reconeixement de la dignitat inherent i dels drets iguals i inalienables de tots els membres de la família humana és el fonament de la llibertat, la justícia i la pau en el món,

Considerant que el desconeixement i el menyspreu dels drets humans han originat actes de barbàrie que han ultratjat la consciència de la humanitat; i que s'ha proclamat com l'aspiració més elevada de tothom l'adveniment d'un món on els éssers humans, deslliurats del temor i la misèria, puguin gaudir de llibertat d'expressió i de creença,

Considerant que és essencial que els drets humans siguin protegits per un règim de dret per tal que les persones no es vegin forçades, com a últim recurs, a la rebel_lió contra la tirania i l'opressió,

Considerant també que és essencial de promoure el desenvolupament de relacions amistoses entre les nacions,

Considerant que els pobles de les Nacions Unides han ratificat en la Carta llur fe en els drets humans fonamentals, en la dignitat i el valor de la persona humana i en la igualtat de dret d'homes i dones; i que han decidit de promoure el progrés social i millorar el nivell de vida dins d'una llibertat més àmplia,

Considerant que els Estats membres s'han compromès a assegurar, en cooperació amb l'Organització de les Nacions Unides, el respecte universal i efectiu dels drets humans i les llibertats fonamentals,

Considerant que una concepció comuna d'aquests drets i llibertats és de la més gran importància per al ple compliment d'aquest compromís,

L'Assemblea General

Proclama aquesta Declaració Universal de Drets Humans com l'ideal comú a assolir per a tots els pobles i nacions amb el fi que cada persona i cada institució, inspirant-se constantment en aquesta Declaració, promoguin, mitjançant I'ensenyament i l'educació, el respecte a aquests drets i llibertats i assegurin, amb mesures progressives nacionals i internacionals, el seu reconeixement i aplicació universals i efectius, tant entre els pobles dels Estats membres com entre els dels territoris sota llur jurisdicció.

Article 1
Tots els éssers humans neixen lliures i iguals en dignitat i en drets. Són dotats de raó i de consciència, i han de comportar-se fraternalment els uns amb els altres.

Article 2
Tothom té tots els drets i llibertats proclamats en aquesta Declaració, sense cap distinció de raça, color, sexe, llengua, religió, opinió política o de qualsevol altra mena, origen nacional o social, fortuna, naixement o altra condició.

A més, no es farà cap distinció basada en l'estatut polític, jurídic o internacional del país o del territori al qual pertanyi una persona, tant si és independent com si està sota administració fiduciària, si no és autònom, o està sota qualsevol altra limitació de sobirania.

Article 3
Tota persona té dret a la vida, a la llibertat i a la seva seguretat.

Article 4
Ningú no serà sotmès a esclavitud o servitud: I'esclavitud i el tràfic d'esclaus són prohibits en totes llurs formes.

Article 5
Ningú no serà sotmès a tortures ni a penes o tractes cruels, inhumans o degradants.

Article 6
Tota persona té el dret arreu al reconeixement de la seva personalitat jurídica.

Article 7
Tots són iguals davant la llei i tenen dret, sense cap distinció, a igual protecció per la llei. Tots tenen dret a igual protecció contra qualsevol discriminació que violi aquesta Declaració i contra qualsevol incitació a una tal discriminació.

Article 8
Tota persona té dret a un recurs efectiu prop dels tribunals nacionals competents que l'empari contra actes que violin els seus drets fonamentals reconeguts per la constitució o per la llei.

Article 9
Ningú no serà detingut, pres o desterrat arbitràriament.

Article 10
Tota persona té dret, en condicions de plena igualtat, a ser escoltada públicament i amb justícia per un tribunal independent i imparcial, per a la determinacio dels seus drets i obligacions o per a l'examen de qualsevol acusació contra ella en matèria penal.

Article 11
Tots els acusats d'un delicte tenen el dret que hom presumeixi la seva innocència fins que no es provi la seva culpabilitat segons la llei en un judici públic, en què hom li hagi assegurat totes les garanties necessàries per a la seva defensa.
Ningú no serà condemnat per actes o omissions que en el moment que varen ésser comesos no eren delictius segons el dret nacional o internacional. Tampoc no s'imposarà cap pena superior a l'aplicable en el moment de cometre el delicte.
Article 12
Ningú no serà objecte d'intromissions arbitràries en la seva vida privada, la seva família, el seu domicili o la seva correspondència, ni d'atacs al seu honor i reputació. Tothom té dret a la protecció de la llei contra tals intromissions o atacs.

Article 13
Tota persona té dret a circular lliurement i a triar la seva residència dins les fronteres de cada Estat.
Tota persona té dret o sortir de qualsevol país, àdhuc el propi, i a retornar-hi.
Article 14
En cas de persecució, tota persona té dret a cercar asil en altres països i a beneficiar-se'n.
Aquest dret no podrà ser invocat contra una persecució veritablement originada per delictes comuns o per actes oposats als objectius i principis de les Nacions Unides.
Article 15
Tota persona té dret a una nacionalitat.
Ningú no serà privat arbitràriament de la seva nacionalitat, ni del dret de canviar de nacionalitat.
Article 16
Els homes i les dones, a partir de l'edat núbil, tenen dret, sense cap restricció per motius de raça, nacionalitat o religió, a casar-se i a fundar una família. Gaudiran de drets iguals pel que fa al casament, durant el matrimoni i en la seva dissolució.
Nomes es realitzarà el casament amb el lliure i ple consentiment dels futurs esposos.
La família és l'element natural i fonamental de la societat i té dret a la protecció de la societat i de l'Estat.
Article 17
Tota persona té dret a la propietat, individualment i col_lectiva.
Ningú no serà privat arbitràriament de la seva propietat.
Article 18
Tota persona té dret a la llibertat de pensament, de consciència i de religió; aquest dret inclou la llibertat de canviar de religió o de creença, i la llibertat, individualment o col lectivament, en públic o en privat, de manifestar la seva religió o creença per mitjà de l'ensenyament, la pràctica, el culte i l'observança.

Article 19
Tota persona té dret a la llibertat d'opinió i d'expressió; aquest dret inclou el de no ser molestat a causa de les pròpies opinions i el de cercar, rebre i difondre les informacions i les idees per qualsevol mitjà i sense límit de fronteres.

Article 20
Tota persona té dret a la llibertat de reunió i d'associació pacífiques.
Ningú no pot ser obligat a pertànyer a una associació.
Article 21
Tota persona té dret a participar en el govern del seu país, directament o per mitjà de representants lliurement elegits.
Tota persona té dret, en condicions d'igualtat, a accedir a les funcions públiques del seu país.
La voluntat del poble és el fonament de l'autoritat de l'Estat; aquesta voluntat ha d'expressar-se mitjançant eleccions autèntiques, que hauran de fer-se periòdicament per sufragi universal i igual i per vot secret o per altre procediment equivalent que garanteixi la llibertat del vot.
Article 22
Tota persona, com a membre de la societat, té dret a la seguretat social i a obtenir, mitjançant l'esforç nacional i la cooperació internacional, segons l'organització i els recursos de cada país, la satisfacció dels drets econòmics, socials i culturals indispensables per a la seva dignitat i el lliure desenvolupament de la seva personalitat.

Article 23
Tota persona té dret al treball, a la lliure elecció de la seva ocupació, a condicions equitatives i satisfactòries de treball, i a la protecció contra l'atur.
Tota persona, sense cap discriminació, té dret a salari igual per igual treball.
Tothom que treballa té dret a una remuneració equitativa i satisfactòria que asseguri per a ell i la seva família una existència conforme a la dignitat humana, completada, si cal, amb altres mitjans de protecció social.
Tothom té dret a constituir sindicats per a la defensa dels seus interessos i a afiliar-s'hi.
Article 24
Tota persona té dret al descans i al lleure i, particularment, a una limitació raonable de la jornada de treball i a vacances periòdiques pagades.

Article 25
Tota persona té dret a un nivell de vida que asseguri, per a ell i la seva família, la salut i el benestar, especialment quant a alimentació, vestir, habitatge, assistència mèdica i als serveis socials necessaris; també té dret a la seguretat en cas d'atur, malaltia, incapacitat, viduïtat, vellesa o altra manca de mitjans de subsistència independent de la seva voluntat.
La maternitat i la infantesa tenen dret a una cura i a una assistència especials. Tots els infants, nascuts d'un matrimoni o fora d'un matrimoni, gaudeixen d'igual protecció social.
Article 26
Tota persona té dret a l'educació. L'educació serà gratuïta, si més no, en la instrucció elemental i fonamental. La instrucció elemental serà obligatòria. L'ensenyament tècnic i professional es posarà a l'abast de tothom, i l'accés a l'ensenyament superior serà igual per a tots en funció dels mèrits respectius.
L'educació tendirà al ple desenvolupament de la personalitat humana i a l'enfortiment del respecte als drets humans i a les llibertats fonamentals; promourà la comprensió, la tolerància i l'amistat entre totes les nacions i grups ètnics o religiosos, i fomentarà les activitats de les Nacions Unides per al manteniment de la pau.
El pare i la mare tenen dret preferent d'escollir la mena d'educació que serà donada als seus fills.
Article 27
Tota persona té dret a participar lliurement en la vida cultural de la comunitat, a gaudir de les arts i a participar i beneficiar-se del progrés científic.
Tota persona té dret a la protecció dels interessos morals i materials derivats de les produccions científiques, literàries o artístiques de què sigui autor.
Article 28
Tota persona té dret a un ordre social i internacional en què els drets i llibertats proclamats en aquesta Declaració puguin ser plenament efectius.

Article 29
Tota persona té deures envers la comunitat, ja que només en aquesta li és possible el lliure i ple desenvolupament de la seva personalitat.
En l'exercici dels drets i les llibertats, tothom estarà sotmès només a les limitacions establertes per la llei i únicament amb la finalitat d'assegurar el reconeixement i el respecte deguts als drets i llibertats dels altres i de complir les justes exigències de la moral, de l'ordre públic i del benestar general en una societat democràtica.
Aquests drets i llibertats mai no podran ser exercits en oposició als objectius i principis de les Nacions Unides.
Article 30
Res en aquesta Declaració no podrà interpretar-se en el sentit que doni cap dret a un Estat, a un grup o a una persona a emprendre activitats o a realitzar actes que tendeixin a la supressió de qualsevol dels drets i llibertats que s'hi enuncien.

TEXT

is(Text::Guess::Language->guess($text),'ca','is ca');

done_testing;
