#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

ადამიანის უფლებათა საყოველთაო დეკლარაცია
მასალა ვიკიპედიიდან — თავისუფალი ენციკლოპედია

ელეონორა რუზველტი და ადამიანის უფლებათა საყოველთაო დეკლარაცია (1949)
ადამიანის უფლებათა საყოველთაო დეკლარაცია — საერთაშორისო აქტი, მიღებული 1948 წლის 10 დეკემბერს გაეროს გენერალური ასამბლეის მიერ. დეკლარაციაში გამოცხადებულია პიროვნების ძირითადი უფლებები - სიცოცხლის, თავისუფლების, პირადი ხელშეუხებლობის, მოქალაქეობის, საცხოვრებელი ადგილის არჩევისა და თავშესაფრის, დემოკრატიული არჩევნების მეშვეობით სახელმწიფოს მართვა გამგეობაში მონაწილეობის, შრომის, თანაბარი შრომისათვის თანაბარი ანაზღაურების მიღების, დასვენების, განათლების, კულტურული ცხოვრებისა თუ მეცნიერულ პროგრესში მონაწილეობის და ა. შ. უფლებები. დეკლარაციით გამოცხადებულია ასევე: რელიგიისა და მრწამსის, კრებებისა და ასოციაციების თავისუფლება; აკრძალულია: მონობა, მონებით ვაჭრობა; ჩამოყალიბებულია სისხლის სამართლის , სისხლის საპროცესო სამართლისა და საოჯახო სამართლის უმთავრესი ძირთადი დემოკრატიული პრინციპები.

დეკლარაციის მოთხოვნაა ეს უფლებები და თავისუფლებები ვრცელდებოდეს ყველა ადამიანზე განურჩევლად რასისა, კანის ფერისა, სქესისა, ენისა, რელიგიისა, პოლიტიკური თუ სხვა მრწამსისა, ეროვნული და სოციალური წარმომავლობისა, წოდებრივი და ქონებრივი ცენზისა.

დეკლარაციის მიღების დღე - 10 დეკემბერი - ადამიანის უფლებათა დღედაა გამოცხადებული და აღინიშნება საერთაშორისო მასშტაბით.

TEXT

is(Text::Guess::Language->guess($text),'ka','is ka');

done_testing;
