#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

ශ්‍රී දළදා මාලිගාව බුදුරජාණන් වහන්සේගේ දන්තධාතූන් අතරින් ශ්‍රී ලංකාවේ ඇති දන්තධාතූන් වහන්සේ වර්තමානයේ තැන්පත් කර ඇති දළදා මාලිගාවයි. මෙය ශ්‍රී ලංකාවේ මහනුවර නගරයේ පිහිටා ඇත. උඩරට රාජ්‍යය සමයේ (1592 සිට 1815) මෙය ඉදිකර ඇත්තේ එවකට රාජකීය මාලිගා සංකීර්ණය තුලමය. අතීතයේ සිටම ජනතාවගේ පිලිගැනීම අනුව දන්ත ධාතූන් වහන්සේගේ භාරකාරීත්වය දරන තැනැත්තා හට ලංකාද්වීපයේ රජකමට හිමිකම ඇත. මේ නිසා අතීතයේ රජවරු සිය දිවි හිමියෙන් දළදා වහන්සේ ආරක්ෂා කළහ. දළදා වහන්සේ වැඩහිටි මන්දිරය, දාඨාධාතුඝරය, දළදාගේ, දළදා මන්දිරය, දළදා මාලිගය ආදී නම් වලින් හැඳින්වූ බව ගෙනේ. දළදා මාලිගාව පිහිටා ඇති මහනුවර නගරයම යුනෙස්කෝව විසින් ලෝක උරුමයක් ලෙස නම් කර ඇත. මල්වතු හෝ අස්ගිරි දෙපාර්ශවයක ස්වාමීන් වහන්සේලා දිනපතාම දළදා වහන්සේට තේවාව නම් පූජා සත්කාරය පවත්වනු ලබයි. මෙම තේවාව දිනකට තුන් වරක් (පාන්දර, දවල් සහ සවස) පවත්වයි. බදාදා දිනවල විශේෂ පූජාවක් ලෙස නානුමුර මංගල්‍යය පවත්වයි. (තව දුරටත්...)


TEXT

is(Text::Guess::Language->guess($text),'si','is si');

done_testing;
