#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;


序言
鉴于对人类家庭所有成员的固有尊严及其平等的和不移的权利的承认,乃是世界自由、正义与和平的基础,

鉴于对人权的无视和侮蔑已发展为野蛮暴行,这些暴行玷污了人类的良心,而一个人人享有言论和信仰自由并免予恐惧和匮乏的世界的来临,已被宣布为普通人民的最高愿望,

鉴于为使人类不致迫不得已铤而走险对暴政和压迫进行反叛,有必要使人权受法治的保护,

鉴于有必要促进各国间友好关系的发展,

鉴于各联合国国家的人民已在联合国宪章中重申他们对基本人权、人格尊严和价值以及男女平等权利的信念,并决心促成较大自由中的社会进步和生活水平的改善,

鉴于各会员国业已誓愿同联合国合作以促进对人权和基本自由的普遍尊重和遵行,

鉴于对这些权利和自由的普遍了解对于这个誓愿的充分实现具有很大的重要性,

因此现在,大会,发布这一世界人权宣言,作为所有人民和所有国家努力实现的共同标准,以期每一个人和社会机构经常铭念本宣言,努力通过教诲和教育促进对权利和自由的尊重,并通过国家的和国际的渐进措施,使这些权利和自由在各会员国本身人民及在其管辖下领土的人民中得到普遍和有效的承认和遵行;

第一条
人人生而自由,在尊严和权利上一律平等。他们赋有理性和良心,并应以兄弟关系的精神相对待。

第二条
人人有资格享有本宣言所载的一切权利和自由,不分种族、肤色、性别、语言、宗教、政治或其他见解、国籍或社会出身、财产、出生或其他身分等任何区别。

并且不得因一人所属的国家或领土的政治的、行政的或者国际的地位之不同而有所区别,无论该领土是独立领土、托管领土、非自治领土或者处于其他任何主权受限制的情况之下。

第三条
人人有权享有生命、自由和人身安全。

第四条
任何人不得使为奴隶或奴役;一切形式的奴隶制度和奴隶买卖,均应予以禁止。

第五条
任何人不得加以酷刑,或施以残忍的、不人道的或侮辱性的待遇或刑罚。

第六条
人人在任何地方有权被承认在法律前的人格。

第七条
法律之前人人平等,并有权享受法律的平等保护,不受任何歧视。人人有权享受平等保护,以免受违反本宣言的任何歧视行为以及煽动这种歧视的任何行为之害。

第八条
任何人当宪法或法律所赋予他的基本权利遭受侵害时,有权由合格的国家法庭对这种侵害行为作有效的补救。

第九条
任何人不得加以任意逮捕、拘禁或放逐。

第十条
人人完全平等地有权由一个独立而无偏倚的法庭进行公正的和公开的审讯,以确定他的权利和义务并判定对他提出的任何刑事指控。

第十一条
㈠凡受刑事控告者,在未经获得辩护上所需的一切保证的公开审判而依法证实有罪以前,有权被视为无罪。
㈡任何人的任何行为或不行为,在其发生时依国家法或国际法均不构成刑事罪者,不得被判为犯有刑事罪。刑罚不得重于犯罪时适用的法律规定。
第十二条
任何人的私生活、家庭、住宅和通信不得任意干涉,他的荣誉和名誉不得加以攻击。人人有权享受法律保护,以免受这种干涉或攻击。

第十三条
㈠人人在各国境内有权自由迁徙和居住。
㈡人人有权离开任何国家,包括其本国在内,并有权返回他的国家。
第十四条
㈠人人有权在其他国家寻求和享受庇护以避免迫害。
㈡在真正由于非政治性的罪行或违背联合国的宗旨和原则的行为而被起诉的情况下,不得援用此种权利。
第十五条
㈠人人有权享有国籍。
㈡任何人的国籍不得任意剥夺,亦不得否认其改变国籍的权利。
第十六条
㈠成年男女,不受种族、国籍或宗教的任何限制有权婚嫁和成立家庭。他们在婚姻方面,在结婚期间和在解除婚约时,应有平等的权利。
㈡只有经男女双方的自由和完全的同意,才能缔婚。
㈢家庭是天然的和基本的社会单元,并应受社会和国家的保护。
第十七条
㈠人人得有单独的财产所有权以及同他人合有的所有权。
㈡任何人的财产不得任意剥夺。
第十八条
人人有思想、良心和宗教自由的权利;此项权利包括改变他的宗教或信仰的自由,以及单独或集体、公开或秘密地以教义、实践、礼拜和戒律表示他的宗教或信仰的自由。

第十九条
人人有权享有主张和发表意见的自由;此项权利包括持有主张而不受干涉的自由,和通过任何媒介和不论国界寻求、接受和传递消息和思想的自由。

第二十条
㈠人人有权享有和平集会和结社的自由。
㈡任何人不得迫使隶属于某一团体。
第二十一条
㈠人人有直接或通过自由选择的代表参与治理本国的权利。
㈡人人有平等机会参加本国公务的权利。
㈢人民的意志是政府权力的基础;这一意志应以定期的和真正的选举予以表现,而选举应依据普遍和平等的投票权,并以不记名投票或相当的自由投票程序进行。
第二十二条
每个人,作为社会的一员,有权享受社会保障,并有权享受他的个人尊严和人格的自由发展所必需的经济、社会和文化方面各种权利的实现,这种实现是通过国家努力和国际合作并依照各国的组织和资源情况。

第二十三条
㈠人人有权工作、自由选择职业、享受公正和合适的工作条件并享受免于失业的保障。
㈡人人有同工同酬的权利,不受任何歧视。
㈢每一个工作的人,有权享受公正和合适的报酬,保证使他本人和家属有一个符合人的生活条件,必要时并辅以其他方式的社会保障。
㈣人人有为维护其利益而组织和参加工会的权利。
第二十四条
人人有享有休息和闲暇的权利,包括工作时间有合理限制和定期给薪休假的权利。

第二十五条
㈠人人有权享受为维持他本人和家属的健康和福利所需的生活水准,包括食物、衣着、住房、医疗和必要的社会服务;在遭到失业、疾病、残废、守寡、衰老或在其他不能控制的情况下丧失谋生能力时,有权享受保障。
㈡母亲和儿童有权享受特别照顾和协助。一切儿童,无论婚生或非婚生,都应享受同样的社会保护。
第二十六条
㈠人人都有受教育的权利,教育应当免费,至少在初级和基本阶段应如此。初级教育应属义务性质。技术和职业教育应普遍设立。高等教育应根据成绩而对一切人平等开放。
㈡教育的目的在于充分发展人的个性并加强对人权和基本自由的尊重。教育应促进各国、各种族或各宗教集团间的了解、容忍和友谊,并应促进联合国维护和平的各项活动。
㈢父母对其子女所应受的教育的种类,有优先选择的权利。
第二十七条
㈠人人有权自由参加社会的文化生活,享受艺术,并分享科学进步及其产生的福利。
㈡人人对由于他所创作的任何科学、文学或美术作品而产生的精神的和物质的利益,有享受保护的权利。
第二十八条
人人有权要求一种社会的和国际的秩序,在这种秩序中,本宣言所载的权利和自由能获得充分实现。

第二十九条
㈠人人对社会负有义务,因为只有在社会中他的个性才可能得到自由和充分的发展。
㈡人人在行使他的权利和自由时,只受法律所确定的限制,确定此种限制的唯一目的在于保证对旁人的权利和自由给予应有的承认和尊重,并在一个民主的社会中适应道德、公共秩序和普遍福利的正当需要。
㈢这些权利和自由的行使,无论在任何情形下均不得违背联合国的宗旨和原则。
第三十条
本宣言的任何条文,不得解释为默许任何国家、集团或个人有权进行任何旨在破坏本宣言所载的任何权利和自由的活动或行为。

TEXT

#is(Text::Guess::Language->guess($text),'zh_zn','is zh_zn');

done_testing;
