#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

UNIVERSELE VERKLARING VAN MENSEREGTE
Aanhef
AANGESIEN erkenning vir die inherente waardigheid en die gelyke en onvervreembare reg van alle lede van die menslike ras die basis vir vryheid, geregtigheid en vrede in die wereld is;

AANGESIEN minagting vir menseregte barbaarse dade wat die gewete van die mens aangetas het en die aanvang van 'n wereld waarin mense vryheid van spraak, geloof, vrees en behoefte het, gesien word as die hoogste aspirasie van die gemiddelde mens;

AANGESIEN dit noodsaaklik is dat menseregte deur die wet beskerm word ten einde te voorkom dat mense nie gedwing gaan word om in opstand teen tirannie en onderdrukking te kom nie;

AANGESIEN dit noodsaaklik is om die ontwikkeling van vriendelike bande tussen nasies aan te moedig;

AANGESIEN die volke wat lid van die Verenigde Volke Organisasie is, hul geloof in fundamentele menseregte in die Handves beklemtoon, in die waardigheid en waarde van die menslike persoon, in die gelyke regte van mans en vrouens en dit ten doel het om sosiale vooruitgang en 'n beter lewenspeil in groter vryheid te bevorder;

AANGESIEN Lidstate hulle voorgeneem het om in samewerking met die Verenigde Volke universele respek en agting vir menseregte en fundamentele vryheid te verwesenlik; en

AANGESIEN 'n algemene begrip van hierdie regte en vryhede van groot belang vir die bereiking van hierdie voorneme is,

Verklaar die ALGEMENE VERGADERING

Hierdie Universele Verklaring van Menseregte as 'n algemene standaard vir die verwesenliking deur alle mense en nasies, om te verseker dat elke individu en elke

deel van die gemeenskap hierdie Verklaring in ag sal neem en deur opvoeding, respek vir hierdie regte en vryhede te bevorder, op nasionale en internasionale vlak, daarna sal strewe om die universele en effektiewe erkenning en agting van hierdie regte te verseker, nie net vir die mense van die Lidstate nie, maar ook vir die mense in die gebiede onder hul jurisdiksie.

Artikel 1
Alle menslike wesens word vry, met gelyke waardigheid en regte, gebore. Hulle het rede en gewete en behoort in die gees van broederskap teenoor mekaar op te tree.

Artikel 2
Elke persoon het die reg tot al die regte en vryhede soos in die Verklaring vervat is, sonder uitsondering van enige aard soos op grond van ras, geslag, kleur, taal, godsdiens,   geboorte of enige ander status.

Daarbenewens sal geen onderskeid op grond van politieke, geregtelike of internasionale status van die land of gebied waartoe 'n persoon behoort gemaak word nie, hetsy dit 'n onafhanklike trust, nie-selfregerend of onder enige ander beperking van soewereiniteit is.

Artikel 3
Elkeen het die reg tot lewe, vryheid en sekuriteit van persoon.

Artikel 4
Niemand sal in slawerny of knegskap gehou word nie; alle vorms van slawerny en handel in slawe sal verbied word.

Artikel 5
Niemand sal gemartel word of aan wrede, onmenslike of vernederende behandeling of straf blootgestel word nie.

Artikel 6
Elkeen het oral die reg tot erkenning as 'n persoon voor die reg.

Artikel 7
Almal is gelyk voor die reg en het die reg tot gelyke beskerming van die wet. Almal het die reg tot gelyke beskerming teen enige diskriminasie ter skending van hierdie Verklaring en teen enige aanmoediging tot sulke diskriminasie.

Artikel 8
Elkeen het die reg tot effektiewe kompensasie deur bevoegde nasionale tribunale vir dade wat hul fundamentele reg skaad wat deur die wet of grondwet aan hulle gegee is.

Artikel 9
Niemand sal aan arbitrêre arrestasie, aanhouding of bannelingskap onderworpe wees nie.

Artikel 10
Elkeen het, in volle gelykheid, die reg tot 'n regverdige en openbare verhoor deur 'n onafhanklike en objektiewe tribunaal, in die bepaling van sy regte en verpligtinge en die ondersoek van enige kriminele saak teen hom.

Artikel 11
Elkeen beskuldig van 'n strafbare oortreding het die reg om as onskuldig beskou te word tot skuldig bevind volgens die wet, in 'n openbare saak waarin hy verseker is van die nodige verdediging.
Niemand sal beskuldig word van 'n strafbare oortreding as gevolg van enige daad of nalatigheid wat volgens nasionale of internasionale wet nie 'n misdaad ten tye van die pleeg daarvan was nie. 'n Swaarder straf sal ook nie opgel word as die straf wat toepaslik was ten tye van die oortreding nie.
Artikel 12
Niemand sal onderworpe wees aan arbitrêre inmenging met sy privaatheid, familie, woning of korrespondensie nie, of aan aanvalle op sy eer en reputasie nie. Elkeen het die reg tot beskerming deur die wet teen sulke inmenging of aanvalle.

Artikel 13
Elkeen het die reg tot vryheid van beweging en verblyf binne die grense van elke staat.
Elkeen het die reg om enige land te verlaat, insluitende sy eie, en na sy land terug te keer.
Artikel 14
Elkeen het die reg tot asiel in ander lande.
Daar mag nie op hierdie reg aanspraak gemaak word tydens vervolging vir nie-politieke oortredings of dade wat strydig is met die doelwitte en beginsels van die Verenigde Volke nie.
Artikel 15
Elkeen het die reg tot burgerskap.
Niemand se burgerskap sal arbitrêr afgeneem word nie en niemand sal van die reg ontneem word om afstand te doen van burgerskap nie.
Artikel 16
Volwasse mans en vrouens, sonder enige beperking as gevolg van ras, nasionaliteit of godsdiens, het die reg om te trou en met 'n familie te begin.Hulle kan aanspraak maak op gelyke regte ten opsigte van die huwelik, tydens die huwelik en tydens ontbinding van die huwelik.
Die huwelik sal plaasvind slegs met die vrywillige en volle toestemming van die voornemende huweliksmaats.
Die familie is die natuurlike en fundamentele groepseenheid van die gemeenskap en kan aanspraak maak op beskerming deur die gemeenskap en die Staat.
Artikel 17
Elkeen het die reg om individueel en in assosiasie met ander eiendom te besit.
Niemand se eiendom sal arbitrêr afgeneem word nie.
Artikel 18
Elkeen het die reg tot vryheid van denke, gewete en godsdiens; hierdie reg sluit in die reg om van godsdiens of geloof te verander en die vryheid om, hetsy alleen of in 'n gemeenskap, hierdie godsdiens of geloof te beoefen deur verkondiging, aanbidding of heiliging.

Artikel 19
Elkeen het die reg tot vryheid van opinie en uitdrukking; hierdie reg sluit die vryheid in om opinies sonder inmenging te lug en om inligting en idees te vra, te ontvang en te deel deur middel van enige medium ten spyte van grense.

Artikel 20
Elkeen het die reg tot vryheid van vreedsame vergadering en assosiasie.
Niemand sal gedwing word om aan 'n assosiasie te behoort nie.
Artikel 21
Elkeen het die reg om aan die regering van sy land deel te neem, hetsy direk of deur vrylik verkose verteenwoordigers.
Elkeen het die reg tot gelyke toegang tot die openbare dienste in sy land.
Die wil van die mense sal die basis vorm van die owerheid of regering, en hierdie wil sal uitgedruk word deur middel van egte tussenverkiesings.
Artikel 22
Elkeen, as 'n lid van die gemeenskap, het die reg tot bestaan-sekerheid en kan aanspraak maak op die verwesenliking van die ekonomiese, sosiale en kulturele regte wat noodsaaklik is vir sy waardigheid en die vrye ontwikkeling van sy persoonlikheid, deur middel van nasionale pogings en internasionale samewerking en volgens die organisasie en hulpbronne van elke staat.

Artikel 23
Elkeen het die reg om te werk, tot die vrye keuse van arbeid, tot regverdige en gunstige werksomstandighede en tot beskerming teen werkloosheid.
Elkeen, sonder diskriminasie, het die reg tot gelyke betaling vir gelyke werk.
Elkeen wat werk kan aanspraak maak op regverdige vergoeding wat aan hom en sy familie 'n menswaardige bestaan verseker en wat aangevul kan word deur ander vorms van sosiale sekerheid, indien nodig.
Elkeen het die reg, ter beskerming van sy belange, om vakbonde te stig en daarby aan te sluit
Artikel 24
Elkeen het die reg tot rus en vrye tyd, insluitend redelike beperkings op werksure en periodieke betaalde verlof.

Artikel 25
Elkeen het die reg tot 'n lewenspeil wat voldoende is vir gesondheid, welsyn vir homself en sy familie, insluitende kos, klere, behuising, mediese sorg en noodsaaklike bestaansekerheid, en die reg tot voordele of onderstandsgeld tydens werkloosheid, siekte, ongeskiktheid, weduweeskap, ouderdom of 'n tekort aan lewens-middele tydens omstandighede buite sy beheer.
Moeders en kinders kan aanspraak maak op spesiale sorg en hulp. Alle kinders, hetsy binne- of buite-egtelik, sal dieselfde sosiale beskerming geniet.
Artikel 26
Elkeen het die reg tot opvoeding. Opvoeding sal gratis wees, ten minste in die elementêre en fundamentele stadiums. Elementêre opvoeding sal verpligtend wees. Tegniese en professionele opvoeding sal geredelik beskikbaar wees en ho‘r opvoeding sal net so geredelik op meriete beskikbaar wees.
Opvoeding sal gemik wees op die volle ontwikkeling van die menslike persoonlikheid en op die bevordering van respek vir menseregte en fundamentele vryheid. Dit sal begrip, verdraag-saamheid en vriendskap tussen alle nasies, rasse of etniese groepe bevorder, asook die aktiwiteite van die Verenigde Volke in die handhawing van vrede.
Ouers het die reg om te kies watter tipe opvoeding hulle kinders ontvang.
Artikel 27
Almal het die reg om vrylik aan die kulturele lewe van hul gemeenskap deel te neem, om die kunste te geniet en in wetenskaplike vooruitgang en voordele te deel.
Elkeen het die reg tot die beskerming van die morele en materi‘le belange wat spruit uit enige wetenskaplike, letterkundige of kunswerk deur hom geproduseer.
Artikel 28
Elkeen is geregtig op 'n sosiale en internasionale orde waarin die regte en vryhede beskryf in hierdie Verklaring ten volle verwesenlik kan word.

Artikel 29
Elkeen het verpligtinge teenoor die gemeenskap waar alleenlik die vrye en volle ontwikkeling van sy persoonlikheid moontlik is.
In die uitoefening van regte en vryhede, sal elke mens slegs onderworpe wees aan die wetlike beperkinge ingestel om deeglike erkenning en respek vir die regte en vryhede van ander te verseker en om die redelike vereistes na te kom vir sedelikheid, openbare orde en die algemene welsyn van 'n demokratiese gemeenskap.
Hierdie regte en vryhede mag in geen geval strydig met die doelwitte en beginsels van die Verenigde Volke uitgeoefen word nie.
Artikel 30
Niks in hierdie Verklaring mag interpreteer word as impliserend dat enige Staat, groep of persoon die reg het om deel te neem aan enige aktiwiteit of enige daad wat gerig is op die beskadiging van enige regte en vryhede hierin beskryf nie.
TEXT

is(Text::Guess::Language->guess($text),'af','is af');

done_testing;
