#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

DEKLARATA E PERGJITHSHME MBI TE DREJTAT E NJERIUT
HYRJE
Mbasi njohja e dinjitetit të lindur të të drejtave të barabarta dhe të patjetërsueshme të të gjithë anëtarëve të familjes njerëzore është themeli i lirisë, drejtësisë dhe paqes në botë;

mbasi mosrespektimi dhe përbuzja e të drejtave të njeriut ka çuar drejt akteve barbare, të cilat kanë ofenduar ndërgjegjen e njerëzimit, dhe mbasi krijimi i botës në të cilën njerëzit do të gëzojnë lirinë e fjalës, të besimit dhe lirinë nga frika e skamja është proklamuar si dëshira më e lartë e çdo njeriu;

mbasi është e nevojshme që të drejtat e njeriut të mbrohen me dispozita juridike, kështu që njeriu të mos jetë i shtrënguar që në pikën e fundit t'i përvishet kryengritjes kundër tiranisë dhe shtypjes;

mbasi është e nevojshme që të nxitet zhvillimi i marrëdhënieve miqësore midis kombeve;

mbasi popujt e Kombeve të Bashkuara vërtetuan përsëri në Kartë besimin e tyre në të drejtat themelore të njeriut, në dinjitetin dhe vlerën e personit të njeriut dhe barazinë midis burrave dhe grave dhe mbasi vendosën që të nxitin përparimin shoqëror dhe të përmirësojnë nivelin e jetës në liri të plotë;

mbasi shtetet anëtare u detyruan që, në bashkëpunim me Kombet e Bashkuara, të sigurojnë respektimin e përgjithshëm dhe zbatimin e të drejtave të njeriut dhe të lirive themelore;

mbasi kuptimi i përbashkët i këtyre të drejtave dhe lirive është më i rëndësishëm për realizimin e plotë të këtij detyrimi;

ASAMBLEJA E PERGJITHSHME shpall Këtë DEKLARATE TE PERGJITHSHME MBI TE DREJTAT E NJERIUT si ideal të përgjithshëm të cilin duhet ta arrijnë të gjithë popujt dhe të gjitha kombet, në mënyrë që çdo njeri dhe çdo organizëm shoqëror, duke pasur parasysh gjithmonë këtë Deklaratë, të përpiqet që, me anë të mësimit dhe edukimit, të ndihmonte në respektimin e këtyre të drejtave dhe lirive dhe që, me anë të masave progresive kombëtare dhe ndërkombëtare, të sigurohej njohja dhe zbatimi i tyre i përgjithshëm dhe i vërtetë, si midis popujve të vetë shteteve anëtare , ashtu edhe midis popujve të atyre territoreve që janë nën administrimin e tyre.

Neni 1.
Të gjithë njerëzit lindin të lirë dhe të barabartë në dinjitet dhe në të drejta. Ata kanë arsye dhe ndërgjegje dhe duhet të sillen ndaj njëri tjetrit me frymë vëllazërimi.

Neni 2.
Secili gëzon të gjitha të drejtat dhe liritë e parashtruara në këtë Deklaratë pa kurrfarë kufizimesh përsa i përket racës, ngjyrës, gjinisë, gjuhës, besimit fetar, mendimit politik ose tjetër, origjinës kombëtare a shoqërore, pasurisë, lindjes ose tjetër.

Asnjë dallim nuk do të bëhet në bazë të statusit politik, juridik ose ndërkombëtar të shtetit ose vendit të cilit i përket çdo njeri, qoftë kur shteti ose vendi është i pavarur, qoftë nën kujdestari, qoftë jo vetëqeverisës ose që gjindet në çfarëdo kushtesh të tjera të kufizimit të sovranitetit.

Neni 3.
Gjithkush ka të drejtë të jetojë, të jetë i lirë dhe të ketë sigurimin vetjak.

Neni 4.
Asnjeri nuk duhet të mbahet si skllav ose çifçi; skllavëria dhe tregtia e skllevërve janë të ndaluara në të gjitha format.

Neni 5.
Asnjeri nuk duhet t'i nënshtrohet mundimit, veprimit ose dënimit të egër, jonjerëzor ose poshtërues.

Neni 6.
Gjithkush ka të drejtë që t'i njihet kudo personaliteti juridik.

Neni 7.
Të gjithë janë të barabartë para ligjit dhe kanë të drejtë pa asnjë diskriminim të mbrohen barabar nga ligji.Të gjithë kanë të drejtën për t'u mbrojtur barabar kundër çdo diskriminimi që cënon këtë Deklaratë, si dhe kundër çdo nxitje për një diskriminim të tillë.

Neni 8.
Gjithkush ka të drejtë për mjete juridike të frytshme para gjykatave kompetente kombëtare për veprimet me të cilat shkelen të drejtat themelore të garantuara nga kushtetuta ose ligjet.

Neni 9.
Asnjeri nuk duhet t'i nënshtrohet arbitrarisht arrestimit, ndalimit ose internimit.

Neni 10.
Gjithkush gëzon njëlloj të drejtën për një proces gjyqësor objektiv e publik para një gjykate të pavarur e të paanshme, në përcaktimin e të drejtave dhe detyrimeve të veta dhe për vendimin mbi çfarëdo lloj akuze penale.

Neni 11.
Kushdo që është i akuzuar për një vepër penale ka të drejtë të konsiderohet i pafajshëm deri sa të vërtetohet fajsia në bazë të ligjit dhe në një proces publik në të cilin ka pasur të gjitha garancitë e duhura për mbrojtjen e vet.
Asnjeri nuk duhet të dënohet për veprime ose mosveprime të cilat nuk përbëjnë një vepër penale, sipas ligjeve kombëtare dhe ndërkombëtare, në kohën kur janë kryer. Gjithashtu nuk mund të vendoset një dënim më i rëndë nga ai që ka qenë zbatuar në kohën kur është kryer vepra penale.
Neni 12.
Asnjeri nuk duhet t'i nënshtrohet ndërhyrjes arbitrare në jetën, familjen, banesën ose korrespondencën vetjake, si dhe sulmeve kundër nderit dhe prestigjit personal. Gjithkush ka të drejtën të mbrohet nga ligji kundër ndërhyrjeve ose sulmeve të tilla.

Neni 13.
Gjithkush ka të drejtën e lirisë së qarkullimit dhe banimit brenda kufijve të çdo shteti.
Gjithkush ka të drejtë të largohet nga cilido vend qoftë, përfshirë këtu edhe të vetin, si dhe të kthehet në vendin e vet.
Neni 14.
Gjithkush ka të drejtë të kërkojë dhe gëzoje në vende të tjera azil nga ndjekjet.
Këtë të drejtë nuk mund ta gëzojë askush në rast se ndiqet për krime jopolitike ose për vepra në kundërshtim me qëllimet dhe parimet e Kombeve të Bashkuara.
Neni 15.
Gjithkush ka të drejtën e një shtetësie.
Asnjeri nuk duhet të privohet arbitrarisht nga shtetësia e tij si dhe as nga e drejta që të ndërrojë shtetësinë.
Neni 16.
Burrat dhe gratë në moshë të pjekur kanë të drejtë të lidhin martesë dhe formojnë familje, pa kurrfarë kufizimi për sa i përket racës, shtetësisë ose besimit. Ata kanë të drejta të barabarta si në rastin e lidhjes së martesës, gjatë martesës si dhe në rast shkurorëzimi.
Martesa duhet të lidhet vetëm me pëlqimin plotësisht të lirë të personave që do të martohen.
Familja është bërthama e natyrshme dhe themelore e shoqërisë dhe ka të drejtën e mbrojtjes nga shoqëria dhe shteti.
Neni 17.
Gjithkush ka të drejtën të ketë pasuri, si vetëm ashtu edhe në bashkësi me të tjerët.
Asnjeri nuk duhet të privohet arbitrarisht nga pasuria e tij.
Neni 18.
Gjithkush ka të drejtën e lirisë së mendimit, ndërgjegjes dhe besimit; kjo e drejtë përfshin lirinë e ndryshimit të besimit ose bindjeve dhe lirinë që njeriu, qoftë vetë ose në bashkësi me të tjerët, të shfaqë publikisht ose privatisht, besimin ose bindjen e vet me anë të dhënies së mësimeve, kryerjes së kultit dhe ceremonive fetare.

Neni 19.
Gjithkush ka të drejtën e lirisë së mendimit dhe të shprehjes; kjo e drejtë përfshin lirinë e mendimit pa ndërhyrje, si dhe lirinë e kërkimit, marrjes dhe njoftimit të informacionit dhe ideve me çfarëdo mjeti qoftë, pa marrë parasysh kufijtë.

Neni 20.
Gjithkush ka të drejtën e lirisë së mbledhjes dhe bashkimit paqësor.
Asnjeri nuk duhet të detyrohet të bëjë pjesë në ndonjë bashkim.
Neni 21.
Gjithkush ka të drejtë të marrë pjesë në qeverisjen e vendit të vet, drejtpërdrejt ose me anë të përfaqsuesve të zgjedhur lirisht.
Gjithkush ka njëlloj të drejtë të hyjë në shërbimet publike në vendin e vet.
Vullneti i popullit është baza e pushtetit shtetëror; ky vullnet duhet të shprehet në zgjedhje periodike dhe të lira të cilat duhet të jenë të përgjithshme dhe votimi i barabartë, si dhe me votim të fshehtë ose sipas procedurës përkatëse të votimit të lirë.
Neni 22.
Si anëtar i shoqërisë, gjithkush ka të drejtën e sigurimit shoqëror dhe realizimit të të drejtave ekonomike, sociale, kulturore të domosdoshme për dinjitetin e vet dhe për zhvillimin e lirë të personalitetit, me ndihmën e shtetit dhe bashkëpunimit ndërkombëtar dhe në përputhje me organizimin dhe mundësitë e çdo shteti.

Neni 23.
Gjithkush ka të drejtën për punë, të zgjedhë lirisht profesionin, të ketë kushte të favorshme pune dhe të jetë i mbrojtur nga papunësia.
Gjithkush, pa kurrfarë diskriminimi, ka të drejtë që për punë të njëjtë të marrë rrogë të njëjtë.
Gjithkush që punon ka të drejtën për një shpërblim të drejtë dhe favorshëm, në mënyrë që t'i sigurojë atij dhe familjes së tij një jetë që i përgjigjet dinjitetit njerëzor dhe, në qoftë se do të jetë e nevojshme ky shpërblim të plotësohet edhe me mjete të tjera të sigurimit shoqëror.
Gjithkush ka të drejtë të formojë sindikatë and të bëjë pjesë në të për mbrojtjen e interesave të veta.
Neni 24.
Gjithkush ka të drejtë për pushim dhe kohë të lirë, duke përfshirë kufizimin e arsyeshëm të orarit të punës dhe pushimin e paguar periodik.

Neni 25.
Gjithkush ka të drejtë për një nivel jetese të mjaftueshëm i cili t'i përgjigjet shëndetit dhe jetës së përshtatshme si të atij personalisht, ashtu edhe të familjes së tij, duke përfshirë ushqimin, veshmbathjen, banesën, kujdesin mjeksor dhe shërbimet e nevojshme sociale, si edhe të drejtën për të qenë i siguruar në rast sëmundjeje, papunësie, vejanie, pleqërie dhe raste të tjera të humbjeve të mjeteve për jetesë për shkak të rrethanave të pavarura nga vullneti i tij.
Nënat dhe fëmijët kanë nevojë për kujdes dhe ndihmë të posaçme. Të gjithë fëmijët, të lindur brenda ose jashtë martese, gëzojnë të njëjtat mbrojtje sociale.
Neni 26.
Gjithkush ka të drejtën e shkollimit. Arsimi duhet të jetë falas, të paktën në shkollat fillore dhe të ulta. Arsimi fillor është i detyrueshëm. Arsimi teknik dhe profesional duhet të zgjerohet e arsimi i lartë duhet t'u bëhet i mundshëm të gjithëve në bazë të aftësisë.
Arsimi duhet të drejtohet nga zhvillimi i plotë i personalitetit të njeriut dhe nga forcimi i respektimit të të drejtave të njeriut dhe lirive themelore. Ai duhet të nxisë kuptimin, tolerancën dhe miqësinë midis të gjithë popujve, grupeve të racave dhe besimeve, si dhe veprimtarinë e Kombeve të Bashkuara për ruajtjen e paqes.
Të drejtën për të zgjedhur llojin e arsimit për fëmijët e tyre e kanë në rradhë të parë prindërit.
Neni 27.
Gjithkush ka të drejtë të marrë pjesë lirisht në jetën kulturore të bashkësisë, të gëzojë artet dhe të përfitojë nga përparimi shkencor dhe dobitë e tij.
Gjithkush ka të drejtë të mbrojë interesat morale dhe materiale, që rrjedhin nga çdo krijimtari shkencore, letrare dhe artistike, autor i të cilave është ai vetë.
Neni 28.
Gjithkush ka të drejtë për një rend shoqëror dhe ndërkombëtar në të cilin mund të realizohen plotësisht të drejtat dhe liritë e shpallura në këtë Deklaratë.

Neni 29.
Gjithkush ka detyrime vetëm ndaj asaj bashkësie në të cilën është i mundur zhvillimi i lirë dhe i plotë i personalitetit të tij.
Në ushtrimin e të drejtave dhe lirive të veta, gjithkush do t'u nënshtrohet vetëm atyre kufizimeve të cilat janë parashikuar me ligj, ekskluzivisht me qëllim që të sigurohet njohja dhe respektimi i nevojshëm i të drejtave dhe lirive të të tjerëve e që të plotësohen kërkesat e drejta të moralit, rendit publik dhe mirëqenies së përgjithshme në shoqërinë demokratike.
(3)Këto të drejta dhe liri nuk mund të zbatohen në asnjë rast kundër qëllimeve dhe parimeve të Kombeve të Bashkuara.
Neni 30.
Asgjë në këtë Deklaratë nuk mund të interpretohet si e drejtë e një shteti, grupi apo personi për të kryer çfarëdo veprimtarie ose për të bërë një akt drejtuar kundër çdo të drejte ose lirie të shpallur në këtë Deklaratë.

TEXT

is(Text::Guess::Language->guess($text),'sq','is sq');

done_testing;
