#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

АДАМ ЌЂЌЫЌТАРЫНЫЊ ЖАЛПЫЃА БІРДЕЙ ДЕКЛАРАЦИЯСЫ
ПРЕАМБУЛА
Адам баласы џйелменініњ барлыќ мџшелеріне тѕн ќадір-ќасиетін, ќђќыќтарыныњ тењдігі мен тартып алынбайтындыѓын тану, бостандыќ пен ѕділдіктіњ жѕне жалпыѓа бірдей бейбітшіліктіњ негізі болып табылатынына назар аудара отырып,

адам ќђќыќтарына деген елемеушілік, менсінбеушілік адам баласы арыныњ зыѓырданын ќайнататын таѓылыќ жаѓдайѓа ѕкеліп соѓатынына жѕне дџние жџзі адамдары сљз бен наным-сенім бостандыќтарына ие болып, џрей мен мђќтаждыќтан ада бола алатын ортаны ќђру - адам баласыныњ жоѓары мѕртебелі ђмтылысы деп жарияланѓанына назар аудара отырып,

адам баласы зорлыќ-зомбылыќ пен ќанауѓа ќарсы кљтеріліске мѕжбџр болатын жаѓдайды тудырмау џшін, адам ќђќыќтары зањ билігімен ќорѓалуы керек екеніне назар аудара отырып,

халыќтар арасында достыќ ќарым-ќатынастыњ дамуына жѕрдемдесу керек екеніне назар аудара отырып,

БіріккенЂлттар елдері љз Жарѓысында негізгі адам ќђќыќтарына, жеке адам басыныњ ќадір-ќасиеті мен ќђндылыѓына жѕне ерлер мен ѕйелдердіњ тењдігіне сенімдерін растап, ѕлеуметтік прогресс пен адамѓа ылайыќ љмір сџру дењгейін, наќтыланѓан бостандыќтардан тыс, кењ ауќымды бостандыќтарды арттыруѓа жѕрдемдесу керек деген шешімге келгендеріне назар аудара отырып,

мџше-мемлекеттер Біріккен Ђлттар Ђйымымен ынтыќтамаса отырып, адам ќђќыќтары мен негізгі бостандыќтары жалпыѓа бірдей ќђрметтеліп саќталуына ыќпал жасауѓа міндеттенгендеріне назар аудара отырып,

осы міндеттемелерді толыќќанды жџзеге асыру жолында осы ќђќыќтар мен бостандыќтардыњ мѕн-маѓынасы мен ерекшелітктерін ђѓынып тџсінудіњ мањызы зор екендігіне назар аудара отырып,

БАС АССАМБЛЕЯ,

Адам ќђќыќтарыныњ жалпыѓа бірдей Декларациясын бџкіл халыќтар мен мемлекеттердіњ ђмтылыстары арќылы ѕр адаммен ќатар, ќоѓамныњ ѕр органы осы декларацияны џнемі жадында тђтып, білім беру жѕне аѓарту жђмыстары арќылы осы ќђќыќтар мен бостандыќтарды ќадір тђтуѓа ыќпал жасап, џлттыќ халыќаралыќ шаралар арќылы Ђйымныњ мџше-мемлекеттерініњ халыќтарымен ќоса, олардыњ юрисдикциясына ќарасты территорялардыњ халыќтары арасында да, жалпыѓа бірдей тиімді тџрде танылып, жџзеге асырылуы џшін алѓа ќойылѓан маќсат ретінде жария етіп отыр.

1 бап
Барлыќ адамдар тумысынан азат жѕне ќадір-ќасиеті мен кђќыќтары тењ болып дџниеге келеді. Адамдарѓа аќыл-парасат, ар-ождан берілген, сондыќтан олар бір-бірімен туыстыќ, бауырмалдыќ ќарым-ќатынас жасаулары тиіс.

2 бап
Ѕр адам, нѕсіліне, тџр-тџсіне, жынысына. тіліне, дініне, саяси немесе басќа да наным-сенімдеріне, ђлттыќ, немесе ѕлеуметтік тегіне, мџліктік. тектік-топтыќ, немесе басќа да жаѓдаяттарѓа ќарамастан осы Декларацияда жарияланѓан барлыќ ќђќыќтар мен бостандыќтарѓа алаланбай, бірдей тењ ие болуы тиіс. Сонымен ќатар, ешкім де љзі тђратын елініњ, не болмаса территорияныњ саяси, ќђќыќтыќ, немесе халыќаралыќ мѕртебесініњ негізі бойынша, жѕне де ол территория тѕуелсіз, ѕлде біреудіњ ќарамаѓында, ѕлде љзін-љзі басќарушы емес, немесе оныњ егемендігі ѕртџрлі нысанда шектеулі болѓан кџнніњ љзінде де, алаланбауы тиіс.

3 бап
Ѕр адам љмір сџруге, бостандыќта болуѓа жѕне оныњ жеке басына ќол сђѓылмауына ќђќылы.

4 бап
Ешкім де ќђлдыќта немесе кіріптарлыќта ђсталуы тиіс емес. Ќђлдыќ пен ќђл саудасына, ќандай тџрде болса да, тыйым салынады.

5 бап
Ешкім де азапталуѓа немесе ќадір-ќасиетін ќорлайтындай адамшылыќќа жатпайтын ќатыгездік жолмен жѕбірленуге, немесе жазалануѓа тиіс емес.

6 бап
Ѕр адам ќай жерде жџрсе де, ќђќыќтыќ субъектісі ретінде танылуына ќђќылы.

7 бап
Зањ алдында жђрттыњ бѕрі тењ жѕне де зањ арќылы алаланбай, бірдей тењ ќорѓалуѓа ќђќылы. Барлыќ адам осы Декларацияныњ ережелерін бђзатын кемсітуден жѕне кемсітуге арандатушылыќтыњ барлыќ тџрінен тењ ќорѓалуѓа ќђќылы.

8 бап
Ѕр адам, конституциямен, немесе зањмен берілген негізгі ќђќыќтары бђзылѓан жаѓдайда, ќђќыѓын ќђзыретті ђлттыќ сот арќылы тиімді тџрде ќалпына келтіруге ќђќылы.

9 бап
Ешкім де негізсіз тђтќындалуѓа, ќамауда ђсталуѓа немесе ќуѓынѓа ђшыратылуѓа тиіс емес.

10 бап
Ѕр адам, љзініњ ќђќыќтары мен міндеттерін аныќтап, љзіне таѓылѓан ќылмыстыќ айыптаудыњ негізділігін белгілеу џшін, ісі толыќ тењдік негізінде, ѕділеттік талаптарѓа сай, тѕуелсіз жѕне ѕділ сот арќылы ашыќ ќаралуына ќђќыѓы бар.

11 бап
Ќылмыс жасады деп айыпталѓан ѕр адам, ќорѓану ќђќыѓы ќамтамасыздандырылып, зањды жѕне ашыќ сот талќылауы оныњ кінѕсін толыќ аныќтаѓанѓа дейін, кінѕсіз деп есептелуге ќђќыѓы бар.
Ешкім де жасаѓан ѕрекеті немесе ѕрекетсіздігі негізінде, егер ол ѕрекеті ђлттыќ зањдар мен халыќаралыќ ќђкыќ бойынша ќылмыс болып саналмаса, жауапќа тартылмайды. Сонымен ќатар ќылмыс џшін берілген жаза, ќылмыс жасалѓан кезде зањмен кљзделген жазадан ауыр болмауѓа тиіс.
12 бап
Ѕр адам жеке жѕне отбасылыќ љміріне љзгелердіњ љз бетінше араласуынан, озбырлыќ жасап баспанасына, хат жазысып-алысу ќђпиясына ќол сђѓуынан, ар-намысы мен абырой беделіне нђќсан келтіруінен ќорѓалуѓа ќђќыѓы бар.

13 бап
Ѕр адамныњ ѕр мемлекеттіњ ішінде жџріп-тђруына жѕне љз ќалауынша тђратын мекен-жайды тањдауына ќђќыѓы бар.
Ѕр адам кез-келген елден, соныњ ішінде љзініњ туѓан елінен, басќа елге ќоныс аударуѓа жѕне љз еліне ќайтып оралуѓа ќђќылы.
14 бап
Ѕр адамныњ ќуѓынѓа ђшыраѓан жаѓдайда, басќа елдерден баспана іздеп жѕне сол баспананы пайдалануѓа кђќыѓы бар.
Бђл ќђќыќ шынтуатында саяси емес ќылмыстыњ негізінде, немесе Біріккен Ђлттар Ђйымыныњ маќсаттары мен ќаѓидаларына ќайшы келетін ѕрекеттері џшін ќуѓындалѓандарѓа жџрмейді.
15 бап
Ѕр адамныњ азаматтыќќа ќђќыѓы бар.
Ешкімді де азаматтыѓынан немесе азаматтыѓын љзгерту ќђќыѓынан еріксіз айыруѓа болмайды.
16 бап
Кѕмелеттік жасќа толѓан ерлер мен ѕйелдер љздерініњ нѕсіліне, ђлтына, дініне ќарамастан некеге тђрып, отбасын ќђруѓа ќђќылы. Олар некеге тђрѓан, некеде болѓан жѕне ажырасќан кезде бірдей кђќыќтарды пайдаланады.
Неке, тек екі жаќтыњ љзара еркін жѕне толыќ келісімі бойынша ѓана ќиылады.
Отабасы ќоѓамныњ табиѓи жѕне негізгі ђясы болып табылады, жѕне ќоѓам мен мемлекет тарапынан ќорѓалуѓа кђќылы.
17 бап.
Ѕр адамныњ дџние мџлікті жеке љзі, немесе басќалармен бірлесіп иемденуге ќђќыѓы бар.
Ешкім де љз мџлкінен еріксіз айрылмауѓа тиіс.
18 бап
Ѕр адам ой-пікір, ар-ождан жѕне дін бостандыѓына ќђќыѓы бар; бђл ќђќыќ љз дінін немесе наным--сенімін љзгерту еркіндігін, љз дінін, наным-сенімін жеке љзі, немесе басќа адамдармен бірігіп тђтып, жария тџрде, немесе жеке жолмен уаѓыздау, ќђдайѓа ќђлшылыќ ету, діни салт-жораларын орындау бостандыѓын да ќамтыйды.

19 бап
Ѕр адам наным-сенім бостандыѓына жѕне љз кљзќарасын еркін білдіруіне ќђќыѓы бар; бђл ќђќыќ љз наным-сенімін кедергісіз ђстану еркіндігін јѕне мемлекеттік шекаралар тѕртібіне тѕуелді болып ќалмай, аќпараттар мен идеяларды еркін іздеп, кез-келген ќђралдар арќылы тарату бостандыѓын да ќамтыйды.

20 бап
Ѕр адамныњ бейбіт жиналыстар жѕне ассоциацияаларды ќђру бостандыѓына ќђќыѓы бар.
Ешкімді де белгілі бір ассоциацияѓа зорлыќпен кіргізуге болмайды.
21 бап
Ѕр адамныњ, љз елін басќару ісіне тікелей љзі, немесе ерікті тџрде сайланѓан љкілдері арќылы ќатысуѓа ќђќыѓы бар.
Ѕр адам љз елінде мемлекеттік ќызметке тењ дѕрежеде ќол жеткізуге ќђќылы.
Халыќтыњ еркі џкімет билігініњ негізі болуы тиіс; бђл ерік мерзімді жѕне бђрмаланбаѓан сайлау арќылы жџзеге асырылуы тиіс . Сайлау жалпыѓа бірдей тењ сайлау ќђќыѓы негізінде, жасырын дауыс беру жолымен, немесе осы сияќты сайлау бостандыѓын ќамтамасыз ететін басќа да, осы мѕндес ѕдістер арќылы љткізілџі тиіс.
22 бап
Ѕр адам, ќоѓам мџшесі ретінде, ѕлеуметтік жаѓынан ќамсыздандырылуына жѕне оныњ ќадір-ќасиеті ќолдау табуына, жеке басы еркін кемелденуіне ќажетті экономикалыќ, ѕлеуметтік жѕне мѕдени салалар бойынша ќђќыќтары ѕрбір мемлекеттіњ ќђрылымы мен рессурстарына сай, ђлттыќ ыкпал жѕне халыкаралыќ ынтымаќтастыќ арќылы жџзеге асырылуына ќђќыгы бар.

23 бап
Ѕр адамныњ ењбек етуге, јђмыс тџрін еркін тањдауѓа, ѕділ жѕне ќолайлы ењбек жаѓдайына, жђмыссыздыќтан ќорѓалуына ќђќыѓы бар.
Ѕр адамныњ ќђндылыѓы тењ ењбегі џшін, нендей бір кемсітусіз, тењ ењбек аќы алуына ќђќыѓы бар.
Жђмыс істеп жџрген ѕр адам љзініњ жѕне отбасыныњ ылайыќты љмір сџруін ќамтамасыз ететіндей ѕділ жѕне ќанаѓаттанарлыќ, жѕне, ќажет болѓан кезде, басќа ѕлеуметтік ќамсыздандыру ќђралдары арќылы толыќтырылып отыратын, сый-сияпатќа ќђќылы.
Ѕр адам кѕсіподаќтарын ќђруѓа жѕне љз мџдделерін ќорѓау џшін, кѕсіподаќтарына кіруге ќђќылы.
24 бап
Ѕр адам тыныѓуѓа жѕне мѕдени демалуѓа, оныњ ішінде аќылѓа ќонымды шектеулі жђмыс кџніне жѕне мерзімді аќылы демалысќа, кђќылы.

25 бап
1.Ѕр адам љзініњ жѕне отбасы мџшелерініњ ден-саулыѓын ѕл-ауќатын ќамтамасыз ететіндей, тамаќты, киімді, баспананы, медициналыќ кџтімді ќамтыйтын љмір сџру дењгейіне ќђќылы жѕне де жђмыссыз ќалѓан кџнде, науќас болѓан кезде, мџгедек болып ќалѓан, жесір болып ќалѓан кџнде, ќартайѓан шаќта, немесе љзіне байланысты емес басќа да себептермен тіршілік ету мџмкіншілігінен айырылып ќалѓан жаѓдайда ќамсыздандырылуына ќђќылы.
Ана жѕне нѕресте болу жаѓдайы айрыќша ќамќорлыќ пен кљмек алуѓа кђќыќ береді.Балалардыњ бѕрі, некелі немесе некесіз туѓан, бірдей ѕлеуметтік ќорѓауды пайдаланады.
26 бап
Ѕр адамныњ білім алуѓа кђќыѓы бар. Білім беру, ењ болмаѓанда бастауыш жѕне жалпы білім, тегін болуы тиіс. Бастауыш білім баршаѓа міндетті болуы тиіс. Техникалыќ жѕне кѕсіптік білім кљпшіліктіњ ќолы жетерліктей болуы тиіс жѕне жоѓары білім де, ѕркімніњ ќабілетіне ќарай кљпшіліктіњ ќолы жетерліктей болуы тиіс.
Білім беру адамныњ жеке басыныњ толыќ кемелденуіне жѕне кђќыќтары мен негізгі бостандыќтарына деген ќђрметті арттыруѓа баѓытталуы тиіс. Білім беру барлыќ ђлттар, нѕсілдік жѕне діни топтары арасында тџсіністік, шыдамдылыќ пен достыќ ќарым-ќатынас орнатуѓа ыќпал жасап жѕне Біріккен Ђлттар Ђйымыныњ бейбітшілікті ќуаттау жолындаѓы јђмысына ыкпал жасап, дем беруі тиіс.
Ата-аналардыњ љздерініњ жас балаларына білім беру тџрін тањдауда ќђќыѓы басымды
27 бап
Ѕр адам ќоѓамныњ мѕдени љміріне еркін ќатысуѓа, љнерден рахат-лѕззат алуѓа, ѓылыми прогресске ат салысуѓа ѕрі оныњ игілігін пайдалануѓа ќђќылы.
Ѕр адам љзі автор болып табылатын ѓылыми ењбегініњ, ѕдеби немесе кљркем шыѓармаларыныњ нѕтижесінде туындайтын рухани жѕне материалды мџдделерін ќорѓауѓа ќђќылы.
28 бап
Ѕр адам осы декларацияда баянды етілген кђќыќтар мен бостандыќтарды толыќ жџзеге асыра алатын ѕлеуметтік жѕне халыќаралыќ тѕртіпке ќђќылы.

29 бап
Ѕр адамныњ, адам баласыныњ еркін жѕне толыќ кемелденуіне мџмкіншілік беретін ќоѓам алдында міндеттері бар.
Љзініњ ќђќыќтары мен бостандыќтарын жџзеге асыруда ѕр адам тек басќа адамдардыњ ќђќыќтары мен бостандыќтарын тиісті тџрде тану жѕне ќђрметтеу маќсаты кљзделген жаѓдайда ѓана жѕне демократиялыќ ќоѓамдаѓы моральдіњ, ќоѓамдыќ тѕртіп пен игіліктіњ ѕділетті талаптарын ќанаѓаттандыру маќсаты кљзделген жаѓдайда ѓана, зањмен белгіленген шектеуге ђшырауы тиіс.
Осы бостандыќтар мен ќђќыќтарды жџзеге асырылуы Біріккен Ђлттар Ђйымыныњ маќсаттары мен ќаѓидаларына ќайшы келмеуі тиіс.
30 бап
Осы Декларациядаѓы ешбір ќаѓида ќасыбір мемлекетке, адамдар тобына немесе жеке адамдарѓа аталмыш Декларацияда баянды етілген ќђќыќтар мен бостандыќтарды жоятын ќызметпен айналысу немесе іс-ѕрекет жасау ќђќыѓын береді деп пайымдалуы тиіс емес.


TEXT

is(Text::Guess::Language->guess($text),'kk','is kk');

done_testing;
