#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

UNIVERSELE VERKLARING VAN DE RECHTEN VAN DE MENS
Preambule
Overwegende, dat erkenning van de inherente waardigheid en van de gelijke en onvervreemdbare rechten van alle leden van de mensengemeenschap grondslag is voor de vrijheid, gerechtigheid en vrede in de wereld;

Overwegende, dat terzijdestelling van en minachting voor de rechten van de mens geleid hebben tot barbaarse handelingen, die het geweten van de mensheid geweld hebben aangedaan en dat de komst van een wereld, waarin de mensen vrijheid van meningsuiting en geloof zullen genieten, en vrij zullen zijn van vrees en gebrek, is verkondigd als het hoogste ideaal van iedere mens;

Overwegende, dat het van het grootste belang is, dat de rechten van de mens beschermd worden door de suprematie van het recht, opdat de mens niet gedwongen worde om in laatste instantie zijn toevlucht te nemen tot opstand tegen tyrannie en onderdrukking;

Overwegende, dat het van het grootste belang is om de ontwikkeling van vriendschappelijke betrekkingen tussen de naties te bevorderen;

Overwegende, dat de volkeren van de Verenigde Naties in het Handvest hun vertrouwen in de fundamentele rechten van de mens, in de waardigheid en de waarde van de mens en in de gelijke rechten van mannen en vrouwen opnieuw hebben bevestigd, en besloten hebben om sociale vooruitgang en een hogere levensstandaard in groter vrijheid te bevorderen;

Overwegende, dat de Staten, welke Lid zijn van de Verenigde Naties, zich plechtig verbonden hebben om, in samenwerking met de Organisatie van de Verenigde Naties, overal de eerbied voor en inachtneming van de rechten van de mens en de fundamentele vrijheden te bevorderen;

Overwegende, dat het van het grootste belang is voor de volledige nakoming van deze verbintenis, dat een ieder begrip hebbe voor deze rechten en vrijheden;

Op grond daarvan proclameert de Algemene Vergadering deze Universele Verklaring van de Rechten van de Mens als het gemeenschappelijk door alle volkeren en alle naties te bereiken ideaal, opdat ieder individu en elk orgaan van de gemeenschap, met deze verklaring voortdurend voor ogen, er naar zal streven door onderwijs en opvoeding de eerbied voor deze rechten en vrijheden te bevorderen, en door vooruitstrevende maatregelen, op nationaal en internationaal terrein, deze rechten algemeen en daadwerkelijk te doen erkennen en toepassen, zowel onder de volkeren van Staten die Lid van de Verenigde Naties zijn, zelf, als onder de volkeren van gebieden, die onder hun jurisdictie staan:

Artikel 1
Alle mensen worden vrij en gelijk in waardigheid en rechten geboren. Zij zijn begiftigd met verstand en geweten, en behoren zich jegens elkander in een geest van broederschap te gedragen.

Artikel 2
Een ieder heeft aanspraak op alle rechten en vrijheden, in deze Verklaring opgesomd, zonder enig onderscheid van welke aard ook, zoals ras, kleur, geslacht, taal, godsdienst, politieke of andere overtuiging, nationale of maatschappelijke afkomst, eigendom, geboorte of andere status.

Verder zal geen onderscheid worden gemaakt naar de politieke, juridische of internationale status van het land of gebied, waartoe iemand behoort, onverschillig of het een onafhankelijk, trust-, of niet-zelfbesturend gebied betreft, dan wel of er een andere beperking van de soevereiniteit bestaat.

Artikel 3
Een ieder heeft het recht op leven, vrijheid en onschendbaarheid van zijn persoon.

Artikel 4
Niemand zal in slavernij of horigheid gehouden worden. Slavernij en slavenhandel in iedere vorm zijn verboden.

Artikel 5
Niemand zal onderworpen worden aan folteringen, noch aan een wrede, onmenselijke of onterende behandeling of bestraffing.

Artikel 6
Een ieder heeft, waar hij zich ook bevindt, het recht als persoon erkend te worden voor de wet.

Artikel 7
Allen zijn gelijk voor de wet en hebben zonder onderscheid aanspraak op gelijke bescherming door de wet. Allen hebben aanspraak op gelijke bescherming tegen iedere achterstelling in strijd met deze Verklaring en tegen iedere ophitsing tot een dergelijke achterstelling.

Artikel 8
Een ieder heeft recht op daadwerkelijke rechtshulp van bevoegde nationale rechterlijke instanties tegen handelingen, welke in strijd zijn met de grondrechten hem toegekend bij Grondwet of wet.

Artikel 9
Niemand zal onderworpen worden aan willekeurige arrestatie, detentie of verbanning.

Artikel 10
Een ieder heeft, in volle gelijkheid, recht op een eerlijke en openbare behandeling van zijn zaak door een onafhankelijke en onpartijdige rechterlijke instantie bij het vaststellen van zijn rechten en verplichtingen en bij het bepalen van de gegrondheid van een tegen hem ingestelde strafvervolging.

Artikel 11
Een ieder, die wegens een strafbaar feit wordt vervolgd, heeft er recht op voor onschuldig gehouden te worden, totdat zijn schuld krachtens de wet bewezen wordt in een openbare rechtszitting, waarbij hem alle waarborgen, nodig voor zijn verdediging, zijn toegekend.
Niemand zal voor schuldig gehouden worden aan enig strafrechtelijk vergrijp op grond van enige handeling of enig verzuim, welke naar nationaal of internationaal recht geen strafrechtelijk vergrijp betekenden op het tijdstip, waarop de handeling of het verzuim begaan werd. Evenmin zal een zwaardere straf worden opgelegd dan die, welke ten tijde van het begaan van het strafbare feit van toepassing was.
Artikel 12
Niemand zal onderworpen worden aan willekeurige inmenging in zijn persoonlijke aangelegenheden, in zijn gezin, zijn tehuis of zijn briefwisseling, noch aan enige aantasting van zijn eer of goede naam. Tegen een dergelijke inmenging of aantasting heeft een ieder recht op bescherming door de wet.

Artikel 13
Een ieder heeft het recht zich vrijelijk te verplaatsen en te vertoeven binnen de grenzen van elke Staat.
Een ieder heeft het recht welk land ook, met inbegrip van het zijne, te verlaten en naar zijn land terug te keren.
Artikel 14
Een ieder heeft het recht om in andere landen asiel te zoeken en te genieten tegen vervolging.
Op dit recht kan geen beroep worden gedaan ingeval van strafvervolgingen wegens misdrijven van niet-politieke aard of handelingen in strijd met de doeleinden en beginselen van de Verenigde Naties.
Artikel 15
Een ieder heeft het recht op een nationaliteit.
Aan niemand mag willekeurig zijn nationaliteit worden ontnomen, noch het recht worden ontzegd om van nationaliteit te veranderen.
Artikel 16
Zonder enige beperking op grond van ras, nationaliteit of godsdienst, hebben mannen en vrouwen van huwbare leeftijd het recht om te huwen en een gezin te stichten. Zij hebben gelijke rechten wat het huwelijk betreft, tijdens het huwelijk en bij de ontbinding ervan.
Een huwelijk kan slechts worden gesloten met de vrije en volledige toestemming van de aanstaande echtgenoten.
Het gezin is de natuurlijke en fundamentele groepseenheid van de maatschappij en heeft recht op bescherming door de maatschappij en de Staat.
Artikel 17
Een ieder heeft recht op eigendom, hetzij alleen, hetzij tezamen met anderen.
Niemand mag willekeurig van zijn eigendom worden beroofd.
Artikel 18
Een ieder heeft recht op vrijheid van gedachte, geweten en godsdienst;dit recht omvat tevens de vrijheid om van godsdienst of overtuiging te veranderen, alsmede de vrijheid hetzij alleen, hetzij met anderen zowel in het openbaar als in zijn particuliere leven zijn godsdienst of overtuiging te belijden door het onderwijzen ervan, door de praktische toepassing, door eredienst en de inachtneming van de geboden en voorschriften.

Artikel 19
Een ieder heeft recht op vrijheid van mening en meningsuiting. Dit recht omvat de vrijheid om zonder inmenging een mening te koesteren en om door alle middelen en ongeacht grenzen inlichtingen en denkbeelden op te sporen, te ontvangen en door te geven.

Artikel 20
Een ieder heeft recht op vrijheid van vreedzame vereniging en vergadering.
Niemand mag worden gedwongen om tot een vereniging te behoren.
Artikel 21
Een ieder heeft het recht om deel te nemen aan het bestuur van zijn land, rechtstreeks of door middel van vrij gekozen vertegenwoordigers.
Een ieder heeft het recht om op voet van gelijkheid te worden toegelaten tot de overheidsdiensten van zijn land.
De wil van het volk zal de grondslag zijn van het gezag van de Regering; deze wil zal tot uiting komen in periodieke en eerlijke verkiezingen, die gehouden zullen worden krachtens algemeen en gelijkwaardig kiesrecht en bij geheime stemmingen of volgens een procedure, die evenzeer de vrijheid van de stemmen verzekert.
Artikel 22
Een ieder heeft als lid van de gemeenschap recht op maatschappelijke zekerheid en heeft er aanspraak op, dat door middel van nationale inspanning en internationale samenwerking, en overeenkomstig de organisatie en de hulpbronnen van de betreffende Staat, de economische, sociale en culturele rechten, die onmisbaar zijn voor zijn waardigheid en voor de vrije ontplooiing van zijn persoonlijkheid, verwezenlijkt worden.

Artikel 23
Een ieder heeft recht op arbeid, op vrije keuze van beroep, op rechtmatige en gunstige arbeidsvoorwaarden en op bescherming tegen werkloosheid.
Een ieder, zonder enige achterstelling, heeft recht op gelijk loon voor gelijke arbeid.
Een ieder, die arbeid verricht, heeft recht op een rechtvaardige en gunstige beloning, welke hem en zijn gezin een menswaardig bestaan verzekert, welke beloning zo nodig met andere middelen van sociale bescherming zal worden aangevuld.
Een ieder heeft het recht om vakverenigingen op te richten en zich daarbij aan te sluiten ter bescherming van zijn belangen.
Artikel 24
Een ieder heeft recht op rust en op eigen vrije tijd, met inbegrip van een redelijke beperking van de arbeidstijd, en op periodieke vakanties met behoud van loon.

Artikel 25
Een ieder heeft recht op een levensstandaard, die hoog genoeg is voor de gezondheid en het welzijn van zichzelf en zijn gezin, waaronder inbegrepen voeding, kleding, huisvesting en geneeskundige verzorging en de noodzakelijke sociale diensten, alsmede het recht op voorziening in geval van werkloosheid, ziekte, invaliditeit, overlijden van de echtgenoot, ouderdom of een ander gemis aan bestaansmiddelen, ontstaan ten gevolge van omstandigheden onafhankelijk van zijn wil.
Moeder en kind hebben recht op bijzondere zorg en bijstand. Alle kinderen, al dan niet wettig, zullen dezelfde sociale bescherming genieten.
Artikel 26
Een ieder heeft recht op onderwijs; het onderwijs zal kosteloos zijn, althans wat het lager en basisonderwijs betreft. Het lager onderwijs zal verplicht zijn. Ambachtsonderwijs en beroepsopleiding zullen algemeen beschikbaar worden gesteld. Hoger onderwijs zal openstaan voor een ieder, die daartoe de begaafdheid bezit.
Het onderwijs zal gericht zijn op de volle ontwikkeling van de menselijke persoonlijkheid en op de versterking van de eerbied voor de rechten van de mens en de fundamentele vrijheden. Het zal het begrip, de verdraagzaamheid en de vriendschap onder alle naties, rassen of godsdienstige groepen bevorderen en het zal de werkzaamheden van de Verenigde Naties voor de handhaving van de vrede steunen.
Aan de ouders komt in de eerste plaats het recht toe om de soort van opvoeding en onderwijs te kiezen, welke aan hun kinderen zal worden gegeven.
Artikel 27
Een ieder heeft het recht om vrijelijk deel te nemen aan het culturele leven van de gemeenschap, om te genieten van kunst en om deel te hebben aan wetenschappelijke vooruitgang en de vruchten daarvan.
Een ieder heeft het recht op de bescherming van de geestelijke en materiële belangen, voortspruitende uit een wetenschappelijk, letterkundig of artistiek werk, dat hij heeft voortgebracht.
Artikel 28
Een ieder heeft recht op het bestaan van een zodanige maatschappelijke en internationale orde, dat de rechten en vrijheden, in deze Verklaring genoemd, daarin ten volle kunnen worden verwezenlijkt.

Artikel 29
Een ieder heeft plichten jegens de gemeenschap, zonder welke de vrije en volledige ontplooiing van zijn persoonlijkheid niet mogelijk is.
In de uitoefening van zijn rechten en vrijheden zal een ieder slechts onderworpen zijn aan die beperkingen, welke bij de wet zijn vastgesteld en wel uitsluitend ter verzekering van de onmisbare erkenning en eerbiediging van de rechten en vrijheden van anderen en om te voldoen aan de gerechtvaardigde eisen van de moraliteit, de openbare orde en het algemeen welzijn in een democratische gemeenschap.
Deze rechten en vrijheden mogen in geen geval worden uitgeoefend in strijd met de doeleinden en beginselen van de Verenigde Naties.
Artikel 30
Geen bepaling in deze Verklaring zal zodanig mogen worden uitgelegd, dat welke Staat, groep of persoon dan ook, daaraan enig recht kan ontlenen om iets te ondernemen of handelingen van welke aard ook te verrichten, die vernietiging van een van de rechten en vrijheden, in deze Verklaring genoemd, ten doel hebben.

TEXT

is(Text::Guess::Language->guess($text),'nl','is nl');

done_testing;
