#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;




الديباجة
لما كان الاعتراف بالكرامة المتأصلة في جميع أعضاء الأسرة البشرية وبحقوقهم المتساوية الثابتة هو أساس الحرية والعدل والسلام في العالم.

ولما كان تناسي حقوق الإنسان وازدراؤها قد أفضيا إلى أعمال همجية آذت الضمير الإنساني، وكان غاية ما يرنو إليه عامة البشر انبثاق عالم يتمتع فيه الفرد بحرية القول والعقيدة ويتحرر من الفزع والفاقة.

ولما كان من الضروري أن يتولى القانون حماية حقوق الإنسان لكيلا يضطر المرء آخر الأمر إلى التمرد على الاستبداد والظلم.

ولما كان من الجوهري تعزيز تنمية العلاقات الودية بين الدول،

ولما كانت شعوب الأمم المتحدة قد أكدت في الميثاق من جديد إيمانها بحقوق الإنسان الأساسية وبكرامة الفرد وقدره وبما للرجال والنساء من حقوق متساوية وحزمت أمرها على أن تدفع بالرقي الاجتماعي قدماً وأن ترفع مستوى الحياة في جو من الحرية أفسح.

ولما كانت الدول الأعضاء قد تعهدت بالتعاون مع الأمم المتحدة على ضمان اطراد مراعاة حقوق الإنسان والحريات الأساسية واحترامها.

ولما كان للإدراك العام لهذه الحقوق والحريات الأهمية الكبرى للوفاء التام بهذا التعهد.

فإن الجمعية العامة تنادي بهذا الإعلان العالمي لحقوق الإنسان على أنه المستوى المشترك الذي ينبغي أن تستهدفه كافة الشعوب والأمم حتى يسعى كل فرد وهيئة في المجتمع، واضعين على الدوام هذا الإعلان نصب أعينهم، إلى توطيد احترام هذه الحقوق والحريات عن طريق التعليم والتربية واتخاذ إجراءات مطردة، قومية وعالمية، لضمان الاعتراف بها ومراعاتها بصورة عالمية فعالة بين الدول الأعضاء ذاتها وشعوب البقاع الخاضعة لسلطانها.



المادة 1.
يولد جميع الناس أحراراً متساوين في الكرامة والحقوق، وقد وهبوا عقلاً وضميراً وعليهم أن يعامل بعضهم بعضاً بروح الإخاء.
المادة 2.
لكل إنسان حق التمتع بكافة الحقوق والحريات الواردة في هذا الإعلان، دون أي تمييز، كالتمييز بسبب العنصر أو اللون أو الجنس أو اللغة أو الدين أو الرأي السياسي أو أي رأي آخر، أو الأصل الوطني أو الاجتماعي أو الثروة أو الميلاد أو أي وضع آخر، دون أية تفرقة بين الرجال والنساء. وفضلا عما تقدم فلن يكون هناك أي تمييز أساسه الوضع السياسي أو القانوني أو الدولي لبلد أو البقعة التي ينتمي إليها الفرد سواء كان هذا البلد أو تلك البقعة مستقلا أو تحت الوصاية أو غير متمتع بالحكم الذاتي أو كانت سيادته خاضعة لأي قيد من القيود.
المادة 3.
لكل فرد الحق في الحياة والحرية وسلامة شخصه.
المادة 4.
لايجوز استرقاق أو استعباد أي شخص، ويحظر الاسترقاق وتجارة الرقيق بكافة أوضاعهما.
المادة 5.
لايعرض أي إنسان للتعذيب ولا للعقوبات أو المعاملات القاسية أو الوحشية أو الحاطة بالكرامة.
المادة 6.
لكل إنسان أينما وجد الحق في أن يعترف بشخصيته القانونية.
المادة 7.
كل الناس سواسية أمام القانون ولهم الحق في التمتع بحماية متكافئة عنه دون أية تفرقة، كما أن لهم جميعا الحق في حماية متساوية ضد أي تميز يخل بهذا الإعلان وضد أي تحريض على تمييز كهذا.
المادة 8.
لكل شخص الحق في أن يلجأ إلى المحاكم الوطنية لإنصافه عن أعمال فيها اعتداء على الحقوق الأساسية التي يمنحها له القانون.
المادة 9.
لا يجوز القبض على أي إنسان أو حجزه أو نفيه تعسفاً.
المادة 10.
لكل إنسان الحق، على قدم المساواة التامة مع الآخرين، في أن تنظر قضيته أمام محكمة مستقلة نزيهة نظراً عادلاً علنياً للفصل في حقوقه والتزاماته وأية تهمة جنائية توجه إليه.
المادة 11.
( 1 ) كل شخص متهم بجريمة يعتبر بريئاً إلى أن تثبت إدانته قانوناً بمحاكمة علنية تؤمن له فيها الضمانات الضرورية للدفاع عنه.
( 2 ) لا يدان أي شخص من جراء أداة عمل أو الامتناع عن أداة عمل إلا إذا كان ذلك يعتبر جرماً وفقاً للقانون الوطني أو الدولي وقت الارتكاب، كذلك لا توقع عليه عقوبة أشد من تلك التي كان يجوز توقيعها وقت ارتكاب الجريمة.
المادة 12.
لا يعرض أحد لتدخل تعسفي في حياته الخاصة أو أسرته أو مسكنه أو مراسلاته أو لحملات على شرفه وسمعته، ولكل شخص الحق في حماية القانون من مثل هذا التدخل أو تلك الحملات.
المادة 13.
( 1 ) لكل فرد حرية التنقل واختيار محل إقامته داخل حدود كل دولة.
( 2 ) يحق لكل فرد أن يغادر أية بلاد بما في ذلك بلده كما يحق له العودة إليه.
المادة 14.
( 1 ) لكل فرد الحق في أن يلجأ إلى بلاد أخرى أو يحاول الالتجاء إليها هرباً من الاضطهاد.
( 2 ) لا ينتفع بهذا الحق من قدم للمحاكمة في جرائم غير سياسية أو لأعمال تناقض أغراض الأمم المتحدة ومبادئها.
المادة 15.
( 1 ) لكل فرد حق التمتع بجنسية ما.
( 2 ) لا يجوز حرمان شخص من جنسيته تعسفاً أو إنكار حقه في تغييرها.
المادة 16.
( 1 ) للرجل والمرأة متى بلغا سن الزواج حق التزوج وتأسيس أسرة دون أي قيد بسبب الجنس أو الدين، ولهما حقوق متساوية عند الزواج وأثناء قيامه وعند انحلاله.
( 2 ) لا يبرم عقد الزواج إلا برضى الطرفين الراغبين في الزواج رضى كاملاً لا إكراه فيه.
( 3 ) الأسرة هي الوحدة الطبيعية الأساسية للمجتمع ولها حق التمتع بحماية المجتمع والدولة.
المادة 17.
( 1 ) لكل شخص حق التملك بمفرده أو بالاشتراك مع غيره.
( 2 ) لا يجوز تجريد أحد من ملكه تعسفاً.
المادة 18.
لكل شخص الحق في حرية التفكير والضمير والدين، ويشمل هذا الحق حرية تغيير ديانته أو عقيدته، وحرية الإعراب عنهما بالتعليم والممارسة وإقامة الشعائر ومراعاتها سواء أكان ذلك سراً أم مع الجماعة.
المادة 19.
لكل شخص الحق في حرية الرأي والتعبير، ويشمل هذا الحق حرية اعتناق الآراء دون أي تدخل، واستقاء الأنباء والأفكار وتلقيها وإذاعتها بأية وسيلة كانت دون تقيد بالحدود الجغرافية.
المادة 20.
( 1 ) لكل شخص الحق في حرية الاشتراك في الجمعيات والجماعات السلمية.
( 2 ) لا يجوز إرغام أحد على الانضمام إلى جمعية ما.
المادة 21.
( 1 ) لكل فرد الحق في الاشتراك في إدارة الشؤون العامة لبلاده إما مباشرة وإما بواسطة ممثلين يختارون اختياراً حراً.
( 2 ) لكل شخص نفس الحق الذي لغيره في تقلد الوظائف العامة في البلاد.
( 3 ) إن إرادة الشعب هي مصدر سلطة الحكومة، ويعبر عن هذه الإرادة بانتخابات نزيهة دورية تجري على أساس الاقتراع السري وعلى قدم المساواة بين الجميع أو حسب أي إجراء مماثل يضمن حرية التصويت.
المادة 22.
لكل شخص بصفته عضواً في المجتمع الحق في الضمانة الاجتماعية وفي أن تحقق بوساطة المجهود القومي والتعاون الدولي وبما يتفق ونظم كل دولة ومواردها الحقوق الاقتصادية والاجتماعية والتربوية التي لاغنى عنها لكرامته وللنمو الحر لشخصيته.
المادة 23.
( 1 ) لكل شخص الحق في العمل، وله حرية اختياره بشروط عادلة مرضية كما أن له حق الحماية من البطالة.
( 2 ) لكل فرد دون أي تمييز الحق في أجر متساو للعمل.
( 3 ) لكل فرد يقوم بعمل الحق في أجر عادل مرض يكفل له ولأسرته عيشة لائقة بكرامة الإنسان تضاف إليه، عند اللزوم، وسائل أخرى للحماية الاجتماعية.
( 4 ) لكل شخص الحق في أن ينشئ وينضم إلى نقابات حماية لمصلحته
المادة 24.
لكل شخص الحق في الراحة، وفي أوقات الفراغ، ولاسيما في تحديد معقول لساعات العمل وفي عطلات دورية بأجر.
المادة 25.
( 1 ) لكل شخص الحق في مستوى من المعيشة كاف للمحافظة على الصحة والرفاهية له ولأسرته، ويتضمن ذلك التغذية والملبس والمسكن والعناية الطبية وكذلك الخدمات الاجتماعية اللازمة، وله الحق في تأمين معيشته في حالات البطالة والمرض والعجز والترمل والشيخوخة وغير ذلك من فقدان وسائل العيش نتيجة لظروف خارجة عن إرادته.
( 2 ) للأمومة والطفولة الحق في مساعدة ورعاية خاصتين، وينعم كل الأطفال بنفس الحماية الاجتماعية سواء أكانت ولادتهم ناتجة عن رباط شرعي أو بطريقة غير شرعية.
المادة 26.
( 1 ) لكل شخص الحق في التعلم، ويجب أن يكون التعليم في مراحله الأولى والأساسية على الأقل بالمجان، وأن يكون التعليم الأولي إلزامياً وينبغي أن يعمم التعليم الفني والمهني، وأن ييسر القبول للتعليم العالي على قدم المساواة التامة للجميع وعلى أساس الكفاءة.
( 2 ) يجب أن تهدف التربية إلى إنماء شخصية الإنسان إنماء كاملاً، وإلى تعزيز احترام الإنسان والحريات الأساسية وتنمية التفاهم والتسامح والصداقة بين جميع الشعوب والجماعات العنصرية أو الدينية، وإلى زيادة مجهود الأمم المتحدة لحفظ السلام.
( 3 ) للآباء الحق الأول في اختيار نوع تربية أولادهم.
المادة 27.
( 1 ) لكل فرد الحق في أن يشترك اشتراكاً حراً في حياة المجتمع الثقافي وفي الاستمتاع بالفنون والمساهمة في التقدم العلمي والاستفادة من نتائجه.
( 2 ) لكل فرد الحق في حماية المصالح الأدبية والمادية المترتبة على إنتاجه العلمي أو الأدبي أو الفني.
المادة 28.
لكل فرد الحق في التمتع بنظام اجتماعي دولي تتحقق بمقتضاه الحقوق والحريات المنصوص عليها في هذا الإعلان تحققاً تاما.
المادة 29.
( 1 ) على كل فرد واجبات نحو المجتمع الذي يتاح فيه وحده لشخصيته أن تنمو نمواً حراُ كاملاً.
( 2 ) يخضع الفرد في ممارسة حقوقه وحرياته لتلك القيود التي يقررها القانون فقط، لضمان الاعتراف بحقوق الغير وحرياته واحترامها ولتحقيق المقتضيات العادلة للنظام العام والمصلحة العامة والأخلاق في مجتمع ديمقراطي.
( 3 ) لا يصح بحال من الأحوال أن تمارس هذه الحقوق ممارسة تتناقض مع أغراض الأمم المتحدة ومبادئها.
المادة 30.
ليس في هذا الإعلان نص يجوز تأويله على أنه يخول لدولة أو جماعة أو فرد أي حق في القيام بنشاط أو تأدية عمل يهدف إلى هدم الحقوق والحريات الواردة فيه.


TEXT

is(Text::Guess::Language->guess($text),'ar','is ar');

done_testing;
