#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);


my $text =<<'TEXT';
אױסדערװײלטע אַרטיקלען
איבונגען מיינט לויפן, שפּאַצירן, און הייבן שווערע וואָג, האַלט די מוסקלען פונעם קערפער אויפגעפרישט און אַקטיוו צו לעבן לאַנג און געזונט.
קאמוניזם, טייטש: א טעאריע און סיסטעם פון סאציאלע און פאליטישע ארגאניזאציע וועלכע איז געווען א הויפט קראפט אין וועלטליכע פאליטיק פאר רוב יארן אינעם 20סטן יאר-הונדערט. אלס א פאליטישע באוועגונג האט קאמוניזם געזוכט אונטערצואווארפן קאפיטאליזם דורך אן ארבייטערס רעוואלוציע און איינשטעלן א סיסטעם אין וועלכע פראפערטי איז די אייגנשאפט פון א גאנצע באפעלקערונג אינאיינעם אנשטאט אינדיווידועלן.
אלבערט איינשטיין - איז געווען א אידישער פיזיקער און מאטעמאטיקער וואס איז מערסט באקאנט פאר זיין ספעציעלער טעאריע פון רעלאטיוויטעט. אין יאר ה'תרפ"א ; 1921 איז ער באלוינט געווארן מיט דער נאבעל באלוינונג פאר פיזיק.
יידישער לוח איז א יערליכע קאלענדאר וואס האט אין זיך די טעג, מאנאטן און יאר, ווי אויך די פרשת השבוע און ימים טובים. עס קען אויך האבן אין זיך יארצייטן, דף היומי, חק, און אנדערע טעגליכע באזירטע שיעורים.
הארץ אטאקע איז ‫אַן אַקוטע אינפֿאַרקציע פֿון מיִאָקאַרדיום (AMI אָדער, מער געוויינטלעך צווישן דאָקטוירים, MI) איז אַן ערנצטע, פּלוצעמדיקע האַרצקרענק וואָס איז כּולל פֿאַרשיידענע ניוואָען ברוסטווייטיק אָדער אומבאַקוועמקייט, שוואַכקייט, שוויצן, ניט־גוטקייט, ברעכן און קרומע האַרצריטמען, און דערפֿירט טייל מאָל צום פֿאַרלירן די באַוווּסטזײַן.
דער פיטאַגאָראַס פּרינציפּ איז א געאמעטרישער כלל וועלכער איז געווארן באקאנט געמאכט דורך דעם גריכישן פילאסאף און מאטעמאטיקער פיטאגאראס. דער כלל לערנט אז ביי יעדן רעכטווינקל דריי-עקן, וועט די שטח פון א פערפעקטן קעסטל אויפ'ן היפאטענוז (דער שיפער חלק אנטקעגן דעם רעכטווינקל) זיין גלייך ווי די סומע פון ביידע קעסטלעך פון די אנדערע צוויי זייטן.
ר' חיים יוסף דוד אזולאי (חיד"א) איז דער באקאנטער ספרדישער גדול וואס האט באלייכט דעם ספרדישן יידנטום מיט זיין תורה, קדושה און חכמה. ער האט מחבר געווען צענדליקער ספרים אויף אלע תּורה־פּראָפֿעסיעס, ער איז געווען א באקאנטער מענטש אין דער גארער וועלט. ער איז געווען א שד"ר צוויי מאל פון ארץ ישראל קיין חוץ לארץ, וואס האט געזאמלט געלט פאר די ארימע ייִדן אין ארץ ישראל.
ד"ר מרדכי שעכטער (2007-1927), דער דריטער רעדאַקטאָר פֿון אױפֿן שװעל (1957־2004), איז אַ באַװוּסטער ייִדיש־לינגװיסט, ־שרײַבער, און ־לערער. ער איז געבױרן געװאָרן אין טשערנעװיץ (דעמאָלט רומעניע) אין 1927 און האָט געקראָגן זײַן דאָקטאָראַט אין לינגװיסטיק פֿון װינער אוניװערסיטעט אין 1951. פֿון דעמאָלט אָן װױנט ער אין אַמעריקע.
TEXT

is(Text::Guess::Language->guess($text),'yi','is yi');


done_testing;
