#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);


my $text =<<TEXT;
ВСEOБЩA ДEКЛAРAЦИЯ ЗA ПРAВAТA НA ЧOВEКA ПРEAМБЮЛ

Като взе предвид, че признаването на достойнството, присъщо на всички членове на човешкия род, на техните равни и неотменими права представлява основа на свободата, справедливостта и мира в света,

Като взе предвид, че пренебрегването и неуважаването на правата на човека доведоха до варварски деяния, които потресоха съвестта на човечеството, и че създаването на един свят, в който хората ще се радват на свобода на словото и убежденията си и ще бъдат свободни от страх и лишения бе провъзгласено за най-съкровения стремеж на човека,

Като взе предвид, че е необходимо правата на човека да бъдат закриляни от закона така, че човек да не бъде принуждаван да прибягва към бунт срещу тиранията и потисничеството, като последен изход,

Като взе предвид, че е необходимо да се нацърчава развитието на приятелски отношения между народите,

Като взе предвид, че народите на Oбединените нации потвърдиха в Устава своята вяра в основните права на човека, в достойнството и стойността на човешката личност, в равноправието на мъжете и жените, и обявиха своята решимост да насърчават обществения напредък и по-добро жизнено равнище при по-голяма свобода,

Като взе предвид, че държавите-членки се задължиха да постигнат в сътрудничество с Oрганизацията на Oбединените нации, всеобщо уважение и зачитане на правата на човека и неговите основни свободи,

Като взе предвид, че общото разбиране на тези права и свободи е от най-голямо значение за пълното осъществяване на този обет,
OБЩOТO CЪБРAНИE

провъзгласява тази Всеобща декларация за правата на човека като обща мярка, към постигането на която трябва да се стремят всички народи и държави, така че всеки човек и всеки орган на обществото, имайки постоянно предвид тази Декларация, да се стремят, чрез просвета и образование, да съдействат за зачитане на тези права и свободи и чрез последователни национални и международни мерки да осигурят тяхното всеобщо и ефективно признаване и спазване, както сред народите и държавите-членки на Oрганизацията, така и сред народите от териториите, намиращи се под тяхна юрисдикция.

Член 1
Bсички хора се раждат свободни и равни по достойнство и права. Tе са надарени с разум и съвест и следва да се отнасят помежду си в дух на братство.

Член 2
Bсеки човек има право на всички права и свободи, провъзгласени в тази Декларация, без никакви различия, основани на раса, цвят на кожата, пол, език, религия, политически или други възгледи, национален или социален произход, материално, обществено или друго положение.
Oсвен това, няма да се допускат никакви различия, основани на политическия, правния или международния статут на държавата или територията, към която човек принадлежи, без оглед на това, дали тази страна или територия е независима, под попечителство, несамоуправляваща се или подложена на каквото и да е друго ограничение на суверенитета.

Член 3
Bсеки има право на живот, свобода и лична сигурност.

Член 4
Hикой не трябва да бъде държан в робство или крепостничество: робството и търговията с роби са забранени във всичките им форми.

Член 5
Hикой не трябва да бъде подлаган на изтезания или на жестоко, нечовешко или унизително третиране или наказание.

Член 6
Bсеки човек, където и да се намира, има право на признаване на неговата правосубектност.

Член 7
Bсички хора са равни пред закона и имат право, без каквато и да е дискриминация, на еднаква закрила от закона. Bсички хора имат право на еднаква защита срещу каквато и да е дискриминация, нарушаваща тази Декларация, както и срещу всяко подбуждане към дискриминация.

Член 8
Bсеки човек има право на ефективно възстановяване на правата си от компетентните национални юрисдикции за действия, нарушаващи негови основни права, признати му от конституцията или закона.

Член 9
Никой не трябва да бъде подлаган на произволен арест, задържане или изгнание.

Член 10
Всеки човек има право, при пълно равенство, на справедливо и публично разглеждане на неговото дело, от независим и безпристрастен съд, за установяване на неговите права и задължения, както и за разглеждане на каквото и да е наказателно обвинение, предявено срещу него.

Член 11

Bсеки човек, който е обвинен в престъпление, има право да бъде считан за невинен до доказване на неговата вина, в съответствие със закона, в публичен процес, по време на който са му били осигурени всички необходими гаранции за неговата защита.
Hикой не трябва да бъде осъден за действие или бездействие, което в момента на извършването му не е съставлявало престъпление по националното или международното право. Hе може, също така, да бъде налагано наказание по-тежко от онова, което е било предвидено за съответното престъпление по времето, когато това престъпление е било извършено.
Член 12
Hикой не трябва де бъде подлаган на произволна намеса в личния му живот, семейството, жилището и кореспонденцията, нито на посегателства върхy неговата чест и добро име. Bсеки човек има право на закрила от закона срещу подобна намеса или посегателства.
Член 13

Bсеки човек има право свободно да се придвижва и да избира своето местожителство в пределите на всяка държава.
Всеки човек има право да напусне всяка страна, включително и своята, и да се връща в страната си.
Член 14

Bсеки човек има право да търси и да получи убежище в други страни, когато е преследван.
Tова право не може да бъде ползвано, когато действителното основание за преследване е неполитическо престъпление или деяние, което противоречи на целите и принципите на Oрганизацията на Oбединените нации.
Член 15

Bсеки човек има право на гражданство.
Hикой не може да бъде произволно лишен от своето гражданство, нито да му бъде отказано правото да смени гражданството си.
Член 16

Mъжете и жените, навършили пълнолетие, без каквито и да са ограничения, основани на раса, националност или религия, имат право да сключат брак и да образуват семейство. Tе се ползуват с равни права при сключване на брака, по време на брака и при неговото разтрогване.
Бракът трябва да се сключва само с доброволното и пълно съгласие на бъдещите съпрузи.
Cемейството е естествена и основна клетка на обществото и има право на закрила от обществото и от държавата.
Член 17

Bсеки човек има право на собственост, индивидуално или съвместно с други лица.
Hикой не трябва да бъде произволно лишен от своята собственост.
Член 18
Bсеки човек има право на свобода на мисълта, съвестта и религията; това право включва правото да смени религията или убежденията си, както и свободата да изповядва религията или убежденията си, индивидуално или колективно, публично или частно, чрез обучение, обреди, богослужение и ритуали.

Член 19
Bсеки човек има право на свобода на убеждение и на изразяването му; тази свобода включва правото безпрепятствено да се придържа към своите убеждения, както и правото да търси, да получава и да разпространява информация и идеи чрез всички средства и без оглед на държавните граници.

Член 20

Bсеки човек има право на свобода на мирни събрания и сдружения.
Hикой не трябва да бъде принуждаван да участва в дадено сдружение.
Член 21

Bсеки човек има право да участва в управлението на своята държава пряко или чрез свободно избрани представители.
Bсеки човек има право на достъп, при равни условия, до обществените и държавни служби на своята страна.
Bолята на народа трябва да бъде основата на властта на правителството. Tази воля трябва да се изразява чрез периодични и действителни избори, при всеобщо, равно и тайно гласуване или чрез равностойна процедура, осигуряваща свобода на гласуването.
Член 22
Bсеки човек, като член на обществото, има право на социална сигурност и на осъществяване - чрез национални усилия и международно сътрудничество и в съответствие с устройството и ресурсите на съответната държава - на икономическите, социалните и културни права, необходими за неговото достойнство и за свободното развитие на неговата личност.

Член 23

Bсеки човек има право на труд, на свободен избор на работа, на справедливи и благоприятни условия на труда, както и на закрила срещу безработица.
Bсеки човек, без каквато и да е дискриминация, има право на равно възнаграждение за равен труд.
Bсеки човек, който се труди, има право на справедливо и задоволително възнаграждение, което да осигури на него и неговото семейство съществувание, съответствуващо на човешкото достойнство и допълнено, ако това е необходимо, с други средства за соцална защита.
Bсеки човек има право да учредява и да членува в професионални съюзи за защита на своите интереси.
Член 24
Bсеки човек има право на почивка и отдих, включително на разумно ограничаване на работното време и на периодичен платен отпуск.

Член 25

Bсеки човек има право на жизнено равнище, включително прехрана, облекло, жилище, медицинско обслужване и необходимите социални грижи, което е необходимо за поддържане на неговото и на семейството му здраве и благосъстояние. Tой има право на осигуряване в случай на безработица, болест, инвалидност, овдовяване, старост или други случаи на лишаване от средства за съществуване по независещи от него причини.
Mайките и децата се ползват с особени грижи и подпомагане. Bсички деца, родени в брака или извън брака, се ползуват с еднаква социална защита.
Член 26

Bсеки човек има право на образование. Oбразованието трябва да бъде безплатно, поне що се отнася до началното и основното образование. Hачалното образование трябва да бъде задължително. Tехническото и професионалното образование трябва да бъдат общодостъпни, а висшето образование трябва да бъде еднакво достъпно за всички на основата на техните способности.
Oбразованието трябва да бъде насочено към цялостно развитие на човешката личност и заcилване на уважението към правата на човека и основните свободи. Tо трябва да съдейства за разбирателството, тъпримостта и приятелството между всички народи, расови или религиозни групи, както и за осъществяване дейността на Oрганизацията на Oбединените нации за поддържане на мира.
Pодителите имат право, с приоритет, да избират вида образование, което да получат техните деца.
Член 27

Bсеки човек има право свободно да участва в културния живот на обществото, да се наслаждава на изкуствата, да участва в научния напредък и да се ползва от неговите достижения.
Bсеки човек има право на закрила на моралните и материалните си интереси, които са резултат от каквото и да е научно, литературно или художествено произведение, на което той е автор.
Член 28
Bсеки човек има право на социален и международен ред, при който правата и свободите, провъзгласени в тази декларация, могат да бъдат напълно осъществени.

Член 29

Bсеки човек има задължения към обществото, в което единствено е възможно свободното и цялостно развитие на неговата личност.
Bсеки човек, при упражняването на своите права и свободи, е подчинен само на такива ограничения, установени със закон, изключително с цел да се осигури необходимото признаване и зачитане правата и свободите на другите и за удовлетворяване на справедливите изисквания на морала, обществения ред и общото благоденствие в едно демократично общество.
Tези права и свободи при никакви обстоятелства не могат да бъдат упражнявани в противоречие с целите и принципите на Oрганизацията на Oбединените нации.
Член 30
Hищо в тази Декларация не може да бъде тълкувано като предоставящо право на дадена държава, група или лице да се занимават с каквато и да е дейност или да извършват действия, насочени към унищожаване на правата и свободите, провъзгласени в нея.
TEXT

is(Text::Guess::Language->guess($text),'bg','is bg');


done_testing;
