#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

VŠOBECNÁ DEKLARÁCIA LUDSKÝCH PRÁV
Úvod
Vo vedomí že uznanie prirodzenej dôstojnosti a rovnych a neodcudzite ľných práv členov ľudskej rodiny je základom slobody, spravodlivosti a mieru na svete,

že zneuznanie ľudských práv a pohrdanie nimi viedlo k barbarským činom, ktoré urážajú svedomie ľudstva, a že vybudovanie sveta, v ktorom ľudia, zbavení strachu a núdze, budú sa tešiť slobode prejavu a presvedčenia, bolo vyhlásené za najvyšší cieľ ľudu,

že je nutné, aby sa ľudsk práva chránily zákonom, ak nemá byť človek donúteý uchýliť sa, keď všetko ostatné zlyhalo, k odboju proti tyranii a útlaku,

že je nutné podporovať rozvoj priateľských vzťahov medzi národmi,

že ľud Spojených národov zdoraznil v Charte znovu svoju vieru v základné ľudské práva, v dostojnosť a hodnotu ľudskej osobnosti, v rovnaké práva mužov a žien a že sa rozhodol podporovať sociálny pokrok a vytvoriť lepšie životné podmienky za vačšej slobody,

že členské štáty prevzaly závazok zaistiť v spolupráci s Organizáciou Spojeých národov všeobecné uznávanie a zachovávanie ľudských práv a základýých slobod a

že rovnaké chápanie týchto práv a slobod má nesmierny význam pre dokonalé splnenie tohto závazku,

vyhlasuje

VALNÉ SHROMAŽDENIE

túto všeobecnú deklaráciu ľudských práv ako spoločný cieľ pre všetky národy a všetky štáty, aby sa každý jednotlivec a každý orgán spoločnosti, majúc túto deklaráciu stále na mysli, snažil vyučovaním a výchovou rozšíriť úctu k týmto právam a slobodám a zaistiť postupnými opatreniami vnútroštátnými i medzinárodnými ich všeobecné a účinné uznávanie a zachovávanie ako medzi ľudom členských štátov samých, tak medzi ľudom území , ktoré sú pod ich právomocou.

Článok 1.
Všetci ľudia sa rodia slobodní a sebe rovní , čo sa týka ich dostojnosti a práv. Sú obdarení rozumom a majú navzájom jednať v bratskom duchu.

Článok 2.
Každý má všetky práva a všetky slobody, vyhlášené v tejto deklarácii, bez hociakého rozlišovania najma pod ľa rasy, farby, pohlavia, jazyka, náboženstva, politického alebo iného smýšľania, národnostného alebo sociálného povodu, majetku, rodu alebo iného postavenia

Žiaden rozdiel sa nebude robiť na podklade politického, právného alebo nedzinárodného postavenia krajiny alebo územia, ku ktorému osoba prí sluší, či je to krajina alebo územie nezávislé alebo pod poručenstvom, nesamosprávne alebo podrobené hociakému inému obmedzeniu suverenity.

Článok 3.
Každý má právo na život, slobodu a osobnú bezpečnosť.

Článok 4.
Nikto sa nesmie držať v otroctve alebo v nevoľníctve: všetky formy otroctva a obchodu s otrokmi sú zakázané.

Článok 5.
Nikto nesmie byť mučený alebo podrobený krutému, neľudskému alebo ponižujúcemu zaobchádzaniu alebo trestu.

Článok 6.
Každý má právo, aby bola všade uznávaná jeho právna osobnosť.

Článok 7.
Všetci sú si pred zákonom rovní a majú právo na rovnakú ochranu zákona bez hociakého rozlišovania. Všetci majú právo na rovnakú ochranu proti hociakej diskriminácii, ktorá porušuje túto deklaráciu, a proti každému podnűcovaniu k takej diskriminácii.

Článok 8.
Každý má právo, aby mu príslušné vnútroštátne súdy poskytly účinnú ochranu proti činom porušujúcim zčkladné práva, ktoré sú mu priznávané ústavou alebo zákonom.

Článok 9.
Nikto nesmie byť svojvoľne zatknutý, držaný vo vazbe alebo vyhnaný do vyhnanstva.

Článok 10.
Každý má úplne rovnaké právo, aby bol spravodlive a verejne vypočutý nezávislým a nestranným súdom, ktorý rozhoduje o jeho právach a povinnostiach a o každom trestnom obvinení, vznesenom proti nemu.

Článok 11.
Každý, kto je obvinený z trestného činu, považuje se za nevinného, dokiaľ nie je zákonným postupom dokázaná jeho vina vo verejnom pokračovaní, pri ktorom mal zaistené všetky možnosti obhajoby.
Nikto nesmie byť odsúdený pre čin alebo opomenutia, ktoré v čase, ked' boly spáchané, neboly trestné podľa štátného alebo medzinárodného práva. Rovnako nesmie byť uložený ťažší trest než trest, ktorý mohol byť uložený v čase, ke trestný čin bol spáchaný.
Článok 12.
Nikto nesmie byť vystavený svojvoľnému zasahovaniu do súkromného života, rodiny, domova alebo korešpondencie, ani útokom na svoju česť a povesť. Každý má právo na zákonnú ochranu proti takýmto zásahom alebo útokom.

Článok 13.
(1) Každý má právo voľne sa pohybovať a slobodne si zvoliť bydlisko v tom - ktorom štáte.
(2) Každý má právo opustiť hociktorú krajinu, i svoju vlastnú, a vrátiť sa do svojej krajiny.
Článok 14.
Každý má právo vyhľadať si pred prenasledovaním útočište v iných krajinách a požívať tam azyl.
Toto právo nemožno uplatňovať v prípade stíhania na ozaj odôvodneného nepolitickými zločinmi alebo činmi, ktoré sú v rozpore s cieľami a zásadami Spojených národov.
Článok 15.
Každý má právo na štátnu príslušnosť.
Nikto nesmie byť svojvoľne zbavený svojej štátnej príslušnosti, ani práva svoju štátnu príslušnosť zmieniť.
Článok 16.
Muži a ženy, ak dosiahli plnoletosť, majú právo bez hociakého obmedzenia z dôvodov rasovej, národnostei alebo náboženskej príslušnosti uzavrieť manželstvo a založiť rodinu. Čo sa manželstva týka, majú počas jeho trvania i pri jeho rozlúčení rovnaké práva.
Manželstvá môžu byť uzavrené len so slobodným a plným súhlasom nastávajúcich manželov.
Rodina je prirodzenou a základnou jednotkou spoločnosti a má nárok na ochranu so strany spoločnosti štátu.
Článok 17.
Každý má právo vlastniť majetok ako sám, tak spolu s inými.
Nikto nesmie byť svojvoľne zbavený svojho majetku.
Článok 18.
Každý má právo na slobodu myslenia, svedomia a náboženstva; toto právo obsahuje aj voľnosť zmeniť náboženstvo alebo vieru, ako i slobodu prejavovať svoje náboženstvo alebo vieru, sám alebo společne s inými, či už verejne alebo súkromne, vyučovaním, vykonávaním náboženských úkonov, bohoslužbou a zachovávaním obradov.

Článok 19.
Každý má právo na slobodu presvedčenia a prejavu: toto právo nepripúšťa, aby niekto trpel ujmu pre svoje presvedčenie a zahrňuje právo vyhľadávať, prijímať a rozširovať informácie a myšlienky hociakými prostriedkami a bez ohľadu na hranice.

Článok 20.
Každému je zaručená sloboda pokojného shromažďovania a sdružovania sa.
Nikto nesmie byť nútený, aby bol členom nejakého sdruženia.
Článok 21.
Každý má právo, aby sa účastnil na vláde svojej krajiny buď priamo, alebo prostredníctvom slobodne volených zástupcov.
Každý má právo vstúpiť za rovnakých podmienok do verejných služieb svojej krajiny.
Vôľa ľudu má byť základom vládnej moci: táto vôľa musí byť vyjadrená správne prevádzanými voľbami, ktoré sa majú konať v pravidelných obdobiach na základe všeobecného a rovného hlasovacieho práva tajným hlasovaním alebo rovnocenným postupom, ktorý zabezpečuje slobodu hlasovania.
Článok 22.
Každý človek má ako člen spoločnosti právo na sociálne zabezpečenie a nárok, aby mu boly národným úsilím i medzinárodnou súčinnosťou a v súlade s organizáciou a prostriedkami príslušného štátu zaistené hospodárske, sociálne a kultúrne práva, potrebné k jeho dôstojnosti a k slobodnému rozvoju jeho osobnosti.

Článok 23.
Každý má právo na prácu, na slobodnú voľbu zamestnania, na spravodlivé a uspokojivé pracovné podmienky a na ochranu proti nezamestnanosti.
Každý, bez hociakého rozlišovania, má nárok na rovnaký plat za rovnakú prácu.
Každý pracujúci má právo na spravodlivú a dostačujúcu odmenu, ktorá by zaisťovala jemu samému a jeho rodine živobytie odpovedajúce ľudskej dôstojnosti, a ktorá by bola doplnená, keby toho bolo treba, inými prostriedkami sociálnej ochrany.
Každý má právo na ochranu svojich záujmov zakladať s inými odborové organizácie a pristupovať k ním.
Článok 24.
Každý má právo na odpočinok a na zotavenie, zvlášť aj na rozumné vymedzenie pracovných hodín a na pravidelnú platenú dovolenku.

Článok 25.
Každý má právo na takú životnú úroveň, ktorá môže zaistiť jeho zdravie a blahobyt a zdravie jeho rodiny, počítajúc v to menovite výživu, šatenie, bývanie a lekárske ošetrovanie, ako aj potrebné sociálne opatrenia: má právo na zabezpečenie v nezamestnanosti, v nemoci, pri neschopnosti k práci, pri ovdovení, v starobe alebo v iných prípadoch straty zárobkových možností, ktoré nastanú za okolností nezávislých ne jeho vôli.
Materstvo a detstvo majú nárok na zvláštnu strarostlivosť a pomoc. Všetky deti, či manželské alebo nemanželské, požívajú rovnakú sociálnu ochranu.
Článok 26.
Každý má právo na vzdelanie. Vzdelanie nech je bezplatné aspoň v začiatočných a základných stupňoch. Základné vzdelanie je povinné. Technické a odborné vzdelanie nech je všeobecne prístupné a vyššie vzdelanie má byť rovnako prístupné každému podľa jeho schopností.
Vzdelanie má smerovať k plnému rozvoju ľudskej osobnosti a k posilneniu úcty k ľudským právam a základným slobodám. Má napomáhať k vzájomnému porozumeniu, snášanlivosti a priateľstvu medzi všetkými národmi a všetkými rasovými i náboženskými skupinami, ako aj k rozvoju činnosti Spojených národov pre zachovanie mieru.
Rodičia majú prednostné právo voliť druh vzdelania pre svoje deti.
Článok 27.
Každý má právo slobodne sa účastniť na kultúrnom živote spoločnosti, užívať plodov umenia a účastniť sa na vedeckom pokroku a jeho výťažkoch.
Každý má právo na ochranu morálnych a materiálnych záujmov, ktoré vyplývajú z jeho vedeckej, literárnej alebo umeleckej tvorby.
Článok 28.
Každý má právo na to, aby vládol taký sociálny a medzinárodný poriadok, v ktorom by práva a slobody vyhlásené v tejto deklarácii boly plne uplatnené.

Článok 29.
Každý má povinnosť voči spoločnosti: jedine v nej môže slobodne a plne rozvinúť svoju osobnosť.
Vo výkone svojich práv a v užívaní svojich slobôd je každý podrobený iba takým obmedzeniam, ktoré stanoví zákon a ktoré slúžia výhradne k zabezpečeniu náležitého, uznávania a zachovávania práv a slobôd iných, ako aj k uspokojeniu spravodlivých požiadaviek mravnosti, verejného poriadku a obecného blaha v demokratiskej spoločnosti.
Výkon týchto práv a slobod nesmie byť v žiadnom prípade v rozpore s cieľami a zásadami Spojených národov.
Článok 30.
V tejto deklarácii nič sa nesmie vykladať tak, aby oprávňovalo ktorýkoľvek štát, skupinu, alebo osobu vyvíjať činnosť alebo dopúšťať sa činov, ktoré by smerovaly k potlačeniu niektorého z práv alebo slobôd v tejto deklarácii vyhlásených.

TEXT

is(Text::Guess::Language->guess($text),'sk','is sk');

done_testing;
